@@ -9,9 +9,11 @@ OC.L10N.register(
     "You made {member} join {circle}" : "Zmusiłeś {member} do przyłączenia się do {circle}",
     "{author} made {member} join {circle}" : "{author} zmusił {member} do przyłączenia się do {circle}",
     "You added team {member} as member to {circle}" : "Dodałeś zespół {member} jako członka do {circle}",
+    "{author} added team {member} as member to {circle}" : "{author} dodał zespół {member} jako członka do {circle}",
     "You made {member} leave {circle}" : "Zmusiłeś {member} do opuszczenia {circle}",
     "{author} made {member} leave {circle}" : "{author} zmusił {member} do opuszczenia {circle}",
     "You removed {member} from {circle}" : "Usunąłeś {member} z {circle}",
+    "{author} removed {member} from {circle}" : "{author} usunął {member} z {circle}",
     "You joined {circle}" : "Dołączyłeś do {circle}",
     "{member} joined {circle}" : "{member} dołączył do {circle}",
     "You accepted the invitation to join {circle}" : "Zaakceptowałeś zaproszenie o dołączenie do {circle}",
@@ -121,12 +123,12 @@ OC.L10N.register(
     "The account is already a member of this circle" : "Konto jest już członkiem tego zespołu",
     "The account has already been invited into this circle" : "Konto zostało już zaproszone do tego zespołu",
     "%s (Team owned by %s)" : "%s (Zespół należący do %s)",
-    "You are now a member of the Circle \"%2$s\"" : "Jesteś teraz członkiem zespołu \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Zostałeś zaproszony przez %1$s do zespołu \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s wysłał prośbę o członkostwo w zespole \"%2$s\"",
+    "You are now a member of the Team \"%2$s\"" : "Jesteś teraz członkiem zespołu „%2$s”",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Zostałeś zaproszony przez %1$s do zespołu „%2$s”",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s wysłał prośbę o dołączenie do zespołu \"%2$s\"",
     "Accept" : "Akceptuj",
     "Refuse" : "Odrzuć",
-    "Leave the circle" : "Opuść zespół",
+    "Leave the team" : "Opuść zespół",
     "%s" : "%s",
     "Personal team" : "Zespół osobisty",
     "%s owned by %s" : "%s należący do %s",
@@ -171,6 +173,10 @@ OC.L10N.register(
     "You cannot join this circle" : "Nie możesz dołączyć do tego kręgu",
     "This member is the owner of the circle" : "Ten członek jest właścicielem kręgu",
     "%s (Circle owned by %s)" : "%s (Okrąg należący do %s)",
+    "You are now a member of the Circle \"%2$s\"" : "Jesteś teraz członkiem zespołu \"%2$s\"",
+    "You have been invited by %1$s into the Circle \"%2$s\"" : "Zostałeś zaproszony przez %1$s do zespołu \"%2$s\"",
+    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s wysłał prośbę o członkostwo w zespole \"%2$s\"",
+    "Leave the circle" : "Opuść zespół",
     "Personal Circle" : "Krąg Osobisty",
     "You need a specify a type of circle" : "Należy podać rodzaj kręgu",
     "A circle with that name exists" : "Krąg o takiej nazwie istnieje",
