@@ -9,9 +9,11 @@ OC.L10N.register(
     "You made {member} join {circle}" : "Ви запросили {member} приєднатися до {circle}",
     "{author} made {member} join {circle}" : "{author} запросив(-ла) {member} приєднатися до {circle}",
     "You added team {member} as member to {circle}" : "Ви запросили {member} стати учасником(-цею) {circle}",
+    "{author} added team {member} as member to {circle}" : "{author} додав(-ла) {member} учасником(-цею) {circle}",
     "You made {member} leave {circle}" : "Ви вилучили {member} із {circle}",
     "{author} made {member} leave {circle}" : "{author} вилучив(-ла) {member} із {circle}",
     "You removed {member} from {circle}" : "Ви вилучили {member} із {circle}",
+    "{author} removed {member} from {circle}" : "{author} вилучив(-ла) {member} із {circle}",
     "You joined {circle}" : "Ви приєдналися до {circle}",
     "{member} joined {circle}" : "{member} приєднався до {circle}",
     "You accepted the invitation to join {circle}" : "Ви прийняли запрошення приєднатися до {circle}",
@@ -121,12 +123,12 @@ OC.L10N.register(
     "The account is already a member of this circle" : "Обліковий запис уже є учасником цього кола",
     "The account has already been invited into this circle" : "Обліковий запис уже запрошено до цього кола",
     "%s (Team owned by %s)" : "%s (власником команди є %s)",
-    "You are now a member of the Circle \"%2$s\"" : "Тепер ви учасник кола \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Вас запросив %1$s до кола \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s надіслав запит на участь у Колі \"%2$s\"",
+    "You are now a member of the Team \"%2$s\"" : "Ви тепер учасник команди \"%2$s\"",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s запросив вас до команди \"%2$s\"",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s додав запит на участь в команді \"%2$s\"",
     "Accept" : "Прийняти",
     "Refuse" : "Відмовитися",
-    "Leave the circle" : "Вийти з кола",
+    "Leave the team" : "Полишити команду",
     "%s" : "%s ",
     "Personal team" : "Приватна команда",
     "%s owned by %s" : "%s належить %s",
@@ -171,6 +173,10 @@ OC.L10N.register(
     "You cannot join this circle" : "Ви не можете приєднатися до цього кола",
     "This member is the owner of the circle" : "Цей учасник є власником кола",
     "%s (Circle owned by %s)" : "%s (Коло належить %s)",
+    "You are now a member of the Circle \"%2$s\"" : "Тепер ви учасник кола \"%2$s\"",
+    "You have been invited by %1$s into the Circle \"%2$s\"" : "Вас запросив %1$s до кола \"%2$s\"",
+    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s надіслав запит на участь у Колі \"%2$s\"",
+    "Leave the circle" : "Вийти з кола",
     "Personal Circle" : "Моє коло",
     "You need a specify a type of circle" : "Потрібно вказати тип кола",
     "A circle with that name exists" : "Коло з такою назвою існує",
