@@ -86,13 +86,33 @@ OC.L10N.register(
     "Organizer:" : "Organizer/организатор/:",
     "Attendees:" : "Участници:",
     "Title:" : "Заглавие:",
-    "Time:" : "Час:",
     "Location:" : "Местоположение:",
     "Link:" : "Връзка:",
     "Accept" : "Приемане",
     "Decline" : "Отхвърляне",
     "More options …" : "Още опции ...",
     "More options at %s" : "Още опции при %s",
+    "Monday" : "Понеделник",
+    "Tuesday" : "Вторник",
+    "Wednesday" : "Сряда",
+    "Thursday" : "Четвъртък",
+    "Friday" : "Петък",
+    "Saturday" : "Събота",
+    "Sunday" : "Неделя",
+    "January" : "Януари",
+    "February" : "Февруари",
+    "March" : "Март",
+    "April" : "Април",
+    "May" : "Май",
+    "June" : "Юни",
+    "July" : "Юли",
+    "August" : "Август",
+    "September" : "Септември",
+    "October" : "Октомври",
+    "November" : "Ноември",
+    "December" : "Декември",
+    "First" : "Първо",
+    "Last" : "Последно",
     "Contacts" : "Контакти",
     "{actor} created address book {addressbook}" : "{actor} създаде адресна книга {addressbook}",
     "You created address book {addressbook}" : "Вие създадохте адресна книга {addressbook}",
@@ -127,12 +147,9 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "Не можа да се преименува частичен файл в краен файл, анулиран е от кука",
     "Could not rename part file to final file" : "Не можа да се преименува частичен файл в краен файл",
     "Failed to check file size: %1$s" : "Неуспешна проверка на размера на файла: %1$s",
-    "Could not open file" : "Файлът не можа да се отвори",
     "Encryption not ready: %1$s" : "Криптирането не е готово: %1$s",
     "Failed to open file: %1$s" : "Неуспешно отваряне на файл: %1$s",
     "Failed to unlink: %1$s" : "Неуспешно прекратяване на връзката: %1$s",
-    "Invalid chunk name" : "Невалидно име на блок",
-    "Could not rename part file assembled from chunks" : "Не можа да се преименува частичен файл, сглобен от блок",
     "Failed to write file contents: %1$s" : "Неуспешно записване на съдържанието на файла: %1$s",
     "File not found: %1$s" : "Файлът не е намерен: %1$s",
     "System is in maintenance mode." : "Системата е в режим на поддръжка.",
@@ -158,13 +175,6 @@ OC.L10N.register(
     "Delete slot" : "Изтриване на слот",
     "No working hours set" : "Няма зададено работно време",
     "Add slot" : "Добавяне на слот",
-    "Monday" : "Понеделник",
-    "Tuesday" : "Вторник",
-    "Wednesday" : "Сряда",
-    "Thursday" : "Четвъртък",
-    "Friday" : "Петък",
-    "Saturday" : "Събота",
-    "Sunday" : "Неделя",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматично задаване на потребителският статус на „Не безпокойте“ извън достъпността, за заглушаване на всички известия.",
     "Failed to load availability" : "Неуспешно зареждане на наличност",
     "Saved availability" : "Запазена наличност",
@@ -188,6 +198,10 @@ OC.L10N.register(
     "Tentative" : "Несигурно",
     "Your attendance was updated successfully." : "Вашето присъствие е актуализирано успешно.",
     "To-dos" : "Задачи за изпълнение",
+    "Time:" : "Час:",
+    "Could not open file" : "Файлът не можа да се отвори",
+    "Invalid chunk name" : "Невалидно име на блок",
+    "Could not rename part file assembled from chunks" : "Не можа да се преименува частичен файл, сглобен от блок",
     "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ако конфигурирате работното си време, другите потребители ще виждат кога сте извън офиса, при резервиране на среща."
 },
 "nplurals=2; plural=(n != 1);");
