@@ -1,120 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "Tiedostoa ei löytynyt",
-    "Move or copy" : "Siirrä tai kopioi",
-    "Download" : "Lataa",
-    "Delete" : "Poista",
-    "Tags" : "Tunnisteet",
-    "Show list view" : "Näytä listanäkymä",
-    "Show grid view" : "Näytä ruudukkonäkymä",
-    "Home" : "Koti",
-    "Close" : "Sulje",
-    "Could not create folder \"{dir}\"" : "Kansiota \"{dir}\" ei voitu luoda",
-    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
-    "Upload cancelled." : "Lähetys peruttu.",
-    "Processing files …" : "Käsitellään tiedostoja…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kohdetta {filename} ei voi lähettää, koska se on joko kansio tai sen koko on 0 tavua",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ei riittävästi vapaata tilaa. Lähetyksesi koko on {size1}, mutta vain {size2} on jäljellä",
-    "Target folder \"{dir}\" does not exist any more" : "Kohdekansio \"{dir}\" ei ole enää olemassa",
-    "Not enough free space" : "Ei tarpeeksi vapaata tilaa",
-    "An unknown error has occurred" : "Tapahtui tuntematon virhe",
-    "File could not be uploaded" : "Tiedostoa ei voi lähettää",
-    "Uploading …" : "Lähetetään…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Lähetetään… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Kyseisen kohteen lähettäminen ei ole tuettu",
-    "Target folder does not exist any more" : "Kohdekansiota ei ole enää olemassa",
-    "Operation is blocked by access control" : "Pääsynhallinta estää toiminnon",
-    "Error when assembling chunks, status code {status}" : "Virhe koottaessa lohkoja, tilakoodi {status}",
-    "Actions" : "Toiminnot",
-    "Rename" : "Nimeä uudelleen",
-    "Move" : "Siirrä",
-    "Copy" : "Kopioi",
-    "Choose target folder" : "Valitse kohdekansio",
-    "Set reminder" : "Aseta muistutus",
-    "Edit locally" : "Muokkaa paikallisesti",
-    "Open" : "Avaa",
-    "Delete file" : "Poista tiedosto",
-    "Delete folder" : "Poista kansio",
-    "Disconnect storage" : "Katkaise yhteys tallennustilaan",
-    "Leave this share" : "Poistu tästä jaosta",
-    "Could not load info for file \"{file}\"" : "Ei voida ladata tiedoston \"{file}\" tietoja",
-    "Files" : "Tiedostot",
-    "Details" : "Tiedot",
-    "Please select tag(s) to add to the selection" : "Valitse lisättävät tunnisteet valinnalle",
-    "Apply tag(s) to selection" : "Hyväksy tunnisteet valinnalle",
-    "Select directory \"{dirName}\"" : "Valitse kansio \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Valitse tiedosto \"{fileName}\"",
-    "Pending" : "Odottaa",
-    "Unable to determine date" : "Päivämäärän määrittäminen epäonnistui",
-    "This operation is forbidden" : "Tämä toiminto on kielletty",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
-    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
-    "Could not move \"{file}\", target exists" : "Tiedoston \"{file}\" siirtäminen ei onnistunut, kohde on olemassa",
-    "Could not move \"{file}\"" : "Tiedoston \"{file}\" siirtäminen ei onnistunut",
-    "copy" : "kopio",
-    "Could not copy \"{file}\", target exists" : "Tiedostoa \"{file}\" ei voitu kopioida, kohde on olemassa",
-    "Could not copy \"{file}\"" : "Tiedostoa \"{file}\" ei voitu kopioida",
-    "Copied {origin} inside {destination}" : "Kopioitu {origin} kohteeseen {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopioitu {origin} ja {nbfiles} muuta tiedostoa kohteeseen {destination}",
-    "Failed to redirect to client" : "Uudelleenohjaus asiakkaaseen epäonnistui",
-    "{newName} already exists" : "{newName} on jo olemassa",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut, koska sitä ei ole enää olemassa",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
-    "Could not rename \"{fileName}\"" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut",
-    "Could not create file \"{file}\"" : "Tiedostoa \"{file}\" ei voitu luoda",
-    "Could not create file \"{file}\" because it already exists" : "Tiedostoa \"{file}\" ei voitu luoda, koska se on jo olemassa",
-    "Could not create folder \"{dir}\" because it already exists" : "Kansiota \"{dir}\" ei voitu luoda, koska se on jo olemassa",
-    "Could not fetch file details \"{file}\"" : "Ei voitu hakea tiedoston tietoja \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Virhe poistaessa tiedostoa \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Kirjoita enemmän kuin kaksi merkkiä etsiäksesi muista kansioista",
-    "Name" : "Nimi",
-    "Size" : "Koko",
-    "Modified" : "Muokattu",
-    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
-    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
-    "{dirs} and {files}" : "{dirs} ja {files}",
-    "_including %n hidden_::_including %n hidden_" : ["Sisältäen %n piilotetun","Sisältäen %n piilotettua"],
-    "You do not have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tähän sijaintiin",
-    "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
-    "New" : "Uusi",
-    "New file/folder menu" : "Uusi tiedosto/kansio -valikko",
-    "Select file range" : "Valitse tiedostojoukko",
-    "{used}%" : "{used} %",
-    "{used} of {quota} used" : "{used}/{quota} käytetty",
-    "{used} used" : "{used} käytetty",
-    "\"{name}\" is an invalid file name." : "\"{name}\" on virheellinen tiedostonimi.",
-    "File name cannot be empty." : "Tiedoston nimi ei voi olla tyhjä.",
-    "\"/\" is not allowed inside a file name." : "\"/\" ei ole sallittu merkki tiedostonimessä.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" ei ole sallittu tiedostomuoto",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Käyttäjän {owner} tallennustila on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ryhmäkansio \"{mountPoint}\" on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Erillinen tallennustila \"{mountPoint}\" on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Tallennustilasi on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Käyttäjän {owner} tallennustila on melkein täynnä ({usedSpacePercent} %)",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ryhmäkansio \"{mountPoint}\" on melkein täynnä ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Erillinen tallennustila \"{mountPoint}\" on melkein täynnä ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Tallennustila on melkein täynnä ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["vastaa \"{filter}\"","vastaa \"{filter}\""],
-    "View in folder" : "Näe kansiossa",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Suora linkki kopioitu (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
-    "Path" : "Polku",
-    "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
-    "Favorited" : "Lisätty suosikkeihin",
-    "Favorite" : "Suosikki",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopioi suora linkki (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
-    "New folder" : "Uusi kansio",
-    "Create new folder" : "Luo uusi kansio",
-    "Upload file" : "Lähetä tiedosto",
-    "Recent" : "Viimeaikaiset",
-    "Not favorited" : "Ei suosikeissa",
-    "Remove from favorites" : "Poista suosikeista",
-    "Add to favorites" : "Lisää suosikkeihin",
-    "An error occurred while trying to update the tags" : "Tunnisteiden päivitystä yrittäessä tapahtui virhe",
     "Added to favorites" : "Lisätty suosikkeihin",
     "Removed from favorites" : "Poistettu suosikeista",
     "You added {file} to your favorites" : "Lisäsit tiedoston {file} suosikkeihin",
@@ -154,8 +40,10 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Siirsit tiedoston {oldfile} tiedostoksi {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} siirsi tiedoston {oldfile} tiedostoksi {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Tiedosto on lisätty tai poistettu <strong>suosikeista</strong>",
+    "Files" : "Tiedostot",
     "A file or folder has been <strong>changed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Suosikkitiedostoa tai -kansiota on <strong>muutettu</strong>",
+    "No favorites" : "Ei suosikkeja",
     "Upload (max. %s)" : "Lähetys (enintään %s)",
     "Accept" : "Hyväksy",
     "Reject" : "Hylkää",
@@ -171,34 +59,48 @@ OC.L10N.register(
     "in %s" : "polussa %s",
     "File Management" : "Tiedostohallinta",
     "Current directory path" : "Nykyisen kansion polku",
+    "Home" : "Koti",
+    "Target folder does not exist any more" : "Kohdekansiota ei ole enää olemassa",
     "Reload current directory" : "Lataa nykyinen kansio uudelleen",
     "Go to the \"{dir}\" directory" : "Siirry kansioon \"{dir}\"",
     "Drag and drop files here to upload" : "Vedä ja pudota tiedostot tähän lähettääksesi",
     "Your have used your space quota and cannot upload files anymore" : "Olet käyttänyt tilakiintiösi, joten et voi lähettää enempää tiedostoja",
     "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
+    "Favorite" : "Suosikki",
+    "Back" : "Takaisin",
+    "File is loading" : "Tiedostoa ladataan",
+    "Folder is loading" : "Kansiota ladataan",
     "Rename file" : "Nimeä tiedosto uudelleen",
     "Filename" : "Tiedostonimi",
     "Folder name" : "Kansion nimi",
     "Invalid filename." : "Epäkelpo tiedostonimi.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Kohteen \"{oldName}\" uudeksi nimeksi asetettiin \"{newName}\"",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Kohdetta \"{oldName}\" ei voitu nimetä uudelleen, koska sitä ei ole enää olemassa",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{newName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
-    "Could not rename \"{oldName}\"" : "Ei voitu nimetä uudelleen \"{oldName}\"",
+    "Unknown date" : "Tuntematon päivämäärä",
+    "Pending" : "Odottaa",
     "Clear filter" : "Tyhjennä suodatin",
+    "Modified" : "Muokattu",
     "Type" : "Tyyppi",
     "Active filters" : "Aktiiviset suodattimet",
     "Remove filter" : "Poista suodatin",
+    "Name" : "Nimi",
+    "Size" : "Koko",
+    "Actions" : "Toiminnot",
+    "(selected)" : "(valittu)",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massatoiminto suoritettu",
     "{count} selected" : "{count} valittu",
     "List of files and folders." : "Luettelo tiedostoista ja kansioista.",
     "Column headers with buttons are sortable." : "Painikkeilla varustetut sarakeotsikot ovat järjestettävissä.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tätä luetteloa ei ole esitetty täysin suorituskykyyn liittyvistä syistä. Tiedostot esitetään sitä mukaa, kun selaat luetteloa.",
     "File not found" : "Tiedostoa ei löytynyt",
+    "Storage information" : "Tallennustilan tiedot",
     "{usedQuotaByte} used" : "{usedQuotaByte} käytetty",
+    "{used} of {quota} used" : "{used}/{quota} käytetty",
     "{relative}% used" : "{relative} % käytetty",
     "Could not refresh storage stats" : "Tallennustilan tilastoja ei voitu päivittää",
     "Your storage is full, files can not be updated or synced anymore!" : "Tallennustila on loppu, tiedostoja ei voi enää päivittää tai synkronoida!",
     "Create" : "Luo",
+    "New folder" : "Uusi kansio",
+    "Create new folder" : "Luo uusi kansio",
     "This name is already in use." : "Tämä nimi on jo käytössä.",
     "Submit" : "Lähetä",
     "Transfer ownership of a file or folder" : "Siirrä tiedoston tai kansion omistajuus",
@@ -213,12 +115,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Pyyntö omistajuuden vaihdosta lähetetty",
     "Cannot transfer ownership of a file or folder you do not own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
     "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
-    "Choose file" : "Valitse tiedosto",
     "Choose {file}" : "Valitse {file}",
     "Loading current folder" : "Ladataan nykyistä kansiota",
+    "Retry" : "Yritä uudelleen",
     "No files in here" : "Täällä ei ole tiedostoja",
     "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
-    "Go to the previous folder" : "Siirry edelliseen kansioon",
     "Go back" : "Mene takaisin",
     "Share" : "Jaa",
     "Shared by link" : "Jaettu linkillä",
@@ -226,6 +127,8 @@ OC.L10N.register(
     "Switch to list view" : "Vaihda taulukkonäkymään",
     "Switch to grid view" : "Vaihda ruudukkonäkymään",
     "Upload was cancelled by user" : "Käyttäjä peruutti latauksen",
+    "Not enough free space" : "Ei tarpeeksi vapaata tilaa",
+    "Operation is blocked by access control" : "Pääsynhallinta estää toiminnon",
     "Error during upload: {message}" : "Virhe lähettäessä: {message}",
     "Error during upload, status code {status}" : "Virhe lähettäessä, tilakoodi {status}",
     "Unknown error during upload" : "Tuntematon virhe lähettämisen aikana",
@@ -247,8 +150,18 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopioi leikepöydälle",
     "Use this address to access your Files via WebDAV" : "Käytä tätä osoitetta yhdistääksesi tiedostosi WebDAV:in kautta",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jos sinulla on kaksivaiheinen todennus käytössä, sinun täytyy luoda uusi sovellussalasana ja käyttää sitä napsauttamalla tästä.",
+    "Keyboard shortcuts" : "Pikanäppäimet",
+    "Selection" : "Valinta",
+    "Navigation" : "Navigointi",
+    "View" : "Näytä",
     "Clipboard is not available" : "Leikepöytä ei ole käytettävissä",
     "WebDAV URL copied to clipboard" : "WebDAV-osoite kopioitu leikepöydälle",
+    "Owner" : "Omistaja",
+    "Remove from favorites" : "Poista suosikeista",
+    "Add to favorites" : "Lisää suosikkeihin",
+    "Tags" : "Tunnisteet",
+    "You" : "Sinä",
+    "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
     "Unable to change the favourite state of the file" : "Suosikki-tilan muuttaminen epäonnistui.",
     "Error while loading the file data" : "Virhe tiedostoa ladatessa",
     "Pick a template for {name}" : "Valtise mallipohja tiedostolle {name}",
@@ -257,15 +170,24 @@ OC.L10N.register(
     "Blank" : "Tyhjä",
     "Unable to create new file from template" : "Uutta tiedostoa mallipohjasta ei voi luoda",
     "Deletion cancelled" : "Poistaminen peruttu",
+    "Leave this share" : "Poistu tästä jaosta",
+    "Disconnect storage" : "Katkaise yhteys tallennustilaan",
+    "Disconnect storages" : "Katkaise yhteys tallennustiloihin",
     "Delete permanently" : "Poista pysyvästi",
     "Delete and unshare" : "Poista ja lopeta jakaminen",
+    "Delete file" : "Poista tiedosto",
     "Delete files" : "Poista tiedostot",
+    "Delete folder" : "Poista kansio",
     "Delete folders" : "Poista kansio",
+    "Delete" : "Poista",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Olet poistamassa {count} kohteen lopullisesti","Olet poistamassa {count} kohdetta lopullisesti"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Olet poistamassa {count} kohteen","Olet poistamassa {count} kohdetta"],
     "Confirm deletion" : "Vahvista poistaminen",
     "Cancel" : "Peruuta",
-    "Destination is not a folder" : "Kohde ei ole kansio",
-    "This file/folder is already in that directory" : "Tämä tiedosto/kansio on jo kyseisessä kansiossa",
+    "Edit file locally" : "Muokkaa tiedostoa paikallisesti",
+    "Retry and close" : "Yritä uudelleen ja sulje",
+    "Failed to redirect to client" : "Uudelleenohjaus asiakkaaseen epäonnistui",
+    "Edit locally" : "Muokkaa paikallisesti",
     "(copy)" : "(kopioi)",
     "Move cancelled" : "Siirtäminen peruttu",
     "A file or folder with that name already exists in this folder" : "Tiedosto tai kansio tällä nimellä on jo olemassa tässä kansiossa",
@@ -273,12 +195,17 @@ OC.L10N.register(
     "The file does not exist anymore" : "Tiedostoa ei ole enää olemassa",
     "Choose destination" : "Valitse kohde",
     "Copy to {target}" : "Kopioi kohteeseen {target}",
+    "Copy" : "Kopioi",
     "Move to {target}" : "Siirrä kohteeseen {target}",
+    "Move" : "Siirrä",
     "Move or copy operation failed" : "Siirto- tai kopiointitoiminto epäonnistui",
+    "Move or copy" : "Siirrä tai kopioi",
     "Cancelled move or copy operation" : "Siirto- tai kopiointitoiminto peruttu",
     "Open folder {displayName}" : "Avaa kansio {displayName}",
     "Open in Files" : "Avaa tiedostosovelluksessa",
+    "Rename" : "Nimeä uudelleen",
     "Open details" : "Avaa yksityiskohdat",
+    "View in folder" : "Näe kansiossa",
     "Today" : "Tänään",
     "Last 7 days" : "Edelliset 7 päivää",
     "Last 30 days" : "Edelliset 30 päivää",
@@ -290,7 +217,9 @@ OC.L10N.register(
     "PDFs" : "PDF-tiedostot",
     "Folders" : "Kansiot",
     "Audio" : "Ääni",
+    "Photos and images" : "Valokuvat ja kuvat",
     "Videos" : "Videot",
+    "New folder creation cancelled" : "Kansion luominen peruttu",
     "Created new folder \"{name}\"" : "Luotu uusi kansio \"{name}\"",
     "Unable to initialize the templates directory" : "Mallipohjien kansiota ei voitu alustaa",
     "Templates" : "Mallipohjat",
@@ -309,6 +238,9 @@ OC.L10N.register(
     "Files copied successfully" : "Tiedostot kopioitu onnistuneesti",
     "Files moved successfully" : "Tiedostot siirretty onnistuneesti",
     "Upload cancelled" : "Lataus peruutettu",
+    "This operation is forbidden" : "Tämä toiminto on kielletty",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
+    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} kansio","{folderCount} kansiota"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} tiedosto","{fileCount} tiedostoa"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 tiedosto ja {folderCount} kansio","1 tiedosto ja {folderCount} kansiota"],
@@ -316,7 +248,6 @@ OC.L10N.register(
     "{fileCount} files and {folderCount} folders" : "{fileCount} tiedostoa ja {folderCount} kansiota",
     "Filename must not be empty." : "Tiedostonimi ei voi olla tyhjä.",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ei ole sallitttu tiedostotyyppi.",
-    "List of favorites files and folders." : "Luettelo suosikkitiedostoista ja -kansioista.",
     "No favorites yet" : "Ei vielä suosikkeja",
     "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
     "All files" : "Kaikki tiedostot",
@@ -326,25 +257,113 @@ OC.L10N.register(
     "List of your files and folders that are not shared." : "Luettelo tiedostoistasi ja kansioistasi, joita ei ole jaettu.",
     "No personal files found" : "Henkilökohtaisia tiedostoja ei löytynyt",
     "Files that are not shared will show up here." : "Tiedostot, joita ei ole jasettu, näkyvät täällä.",
+    "Recent" : "Viimeaikaiset",
     "List of recently modified files and folders." : "Luettelo äskettäin muokatuista tiedostoista ja kansioista.",
     "No recently modified files" : "Ei äskettäin muokattuja tiedostoja",
     "Files and folders you recently modified will show up here." : "Äskettäin muokkaamasi tiedostot ja kansiot näkyvät täällä.",
+    "You do not have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tähän sijaintiin",
     "No entries found in this folder" : "Ei kohteita tässä kansiossa",
     "Select all" : "Valitse kaikki",
     "Upload too large" : "Lähetettävä tiedosto on liian suuri",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
-    "Text file" : "Tekstitiedosto",
-    "New text file.txt" : "Uusi tekstitiedosto.txt",
+    "File could not be found" : "Tiedostoa ei löytynyt",
+    "Download" : "Lataa",
+    "Show list view" : "Näytä listanäkymä",
+    "Show grid view" : "Näytä ruudukkonäkymä",
+    "Close" : "Sulje",
+    "Could not create folder \"{dir}\"" : "Kansiota \"{dir}\" ei voitu luoda",
+    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
+    "Upload cancelled." : "Lähetys peruttu.",
+    "Processing files …" : "Käsitellään tiedostoja…",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kohdetta {filename} ei voi lähettää, koska se on joko kansio tai sen koko on 0 tavua",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ei riittävästi vapaata tilaa. Lähetyksesi koko on {size1}, mutta vain {size2} on jäljellä",
+    "Target folder \"{dir}\" does not exist any more" : "Kohdekansio \"{dir}\" ei ole enää olemassa",
+    "An unknown error has occurred" : "Tapahtui tuntematon virhe",
+    "File could not be uploaded" : "Tiedostoa ei voi lähettää",
+    "Uploading …" : "Lähetetään…",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Lähetetään… ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Kyseisen kohteen lähettäminen ei ole tuettu",
+    "Error when assembling chunks, status code {status}" : "Virhe koottaessa lohkoja, tilakoodi {status}",
+    "Choose target folder" : "Valitse kohdekansio",
+    "Set reminder" : "Aseta muistutus",
+    "Open" : "Avaa",
+    "Could not load info for file \"{file}\"" : "Ei voida ladata tiedoston \"{file}\" tietoja",
+    "Details" : "Tiedot",
+    "Please select tag(s) to add to the selection" : "Valitse lisättävät tunnisteet valinnalle",
+    "Apply tag(s) to selection" : "Hyväksy tunnisteet valinnalle",
+    "Select directory \"{dirName}\"" : "Valitse kansio \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Valitse tiedosto \"{fileName}\"",
+    "Unable to determine date" : "Päivämäärän määrittäminen epäonnistui",
+    "Could not move \"{file}\", target exists" : "Tiedoston \"{file}\" siirtäminen ei onnistunut, kohde on olemassa",
+    "Could not move \"{file}\"" : "Tiedoston \"{file}\" siirtäminen ei onnistunut",
+    "copy" : "kopio",
+    "Could not copy \"{file}\", target exists" : "Tiedostoa \"{file}\" ei voitu kopioida, kohde on olemassa",
+    "Could not copy \"{file}\"" : "Tiedostoa \"{file}\" ei voitu kopioida",
+    "Copied {origin} inside {destination}" : "Kopioitu {origin} kohteeseen {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopioitu {origin} ja {nbfiles} muuta tiedostoa kohteeseen {destination}",
+    "{newName} already exists" : "{newName} on jo olemassa",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut, koska sitä ei ole enää olemassa",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
+    "Could not rename \"{fileName}\"" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut",
+    "Could not create file \"{file}\"" : "Tiedostoa \"{file}\" ei voitu luoda",
+    "Could not create file \"{file}\" because it already exists" : "Tiedostoa \"{file}\" ei voitu luoda, koska se on jo olemassa",
+    "Could not create folder \"{dir}\" because it already exists" : "Kansiota \"{dir}\" ei voitu luoda, koska se on jo olemassa",
+    "Could not fetch file details \"{file}\"" : "Ei voitu hakea tiedoston tietoja \"{file}\"",
+    "Error deleting file \"{fileName}\"." : "Virhe poistaessa tiedostoa \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "Kirjoita enemmän kuin kaksi merkkiä etsiäksesi muista kansioista",
+    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
+    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
+    "{dirs} and {files}" : "{dirs} ja {files}",
+    "_including %n hidden_::_including %n hidden_" : ["Sisältäen %n piilotetun","Sisältäen %n piilotettua"],
+    "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
+    "New" : "Uusi",
+    "New file/folder menu" : "Uusi tiedosto/kansio -valikko",
+    "Select file range" : "Valitse tiedostojoukko",
+    "{used}%" : "{used} %",
+    "{used} used" : "{used} käytetty",
+    "\"{name}\" is an invalid file name." : "\"{name}\" on virheellinen tiedostonimi.",
+    "File name cannot be empty." : "Tiedoston nimi ei voi olla tyhjä.",
+    "\"/\" is not allowed inside a file name." : "\"/\" ei ole sallittu merkki tiedostonimessä.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" ei ole sallittu tiedostomuoto",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Käyttäjän {owner} tallennustila on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ryhmäkansio \"{mountPoint}\" on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Erillinen tallennustila \"{mountPoint}\" on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Tallennustilasi on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Käyttäjän {owner} tallennustila on melkein täynnä ({usedSpacePercent} %)",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ryhmäkansio \"{mountPoint}\" on melkein täynnä ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Erillinen tallennustila \"{mountPoint}\" on melkein täynnä ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Tallennustila on melkein täynnä ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["vastaa \"{filter}\"","vastaa \"{filter}\""],
     "Direct link was copied (only works for users who have access to this file/folder)" : "Suoralinkki kopioitiin (toimii vain niillä käyttäjillä, joilla on pääsy kyseiseen tiedostoon/kansioon)",
+    "Path" : "Polku",
+    "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
+    "Favorited" : "Lisätty suosikkeihin",
     "Copy direct link (only works for users who have access to this file/folder)" : "Kopioi suora linkki (toimii vain käyttäjillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
+    "Upload file" : "Lähetä tiedosto",
+    "Not favorited" : "Ei suosikeissa",
+    "An error occurred while trying to update the tags" : "Tunnisteiden päivitystä yrittäessä tapahtui virhe",
     "\"remote user\"" : "\"etäkäyttäjä\"",
     "{newName} already exists." : "{newName} on jo olemassa.",
     "Name cannot be empty" : "Nimi ei voi olla tyhjä",
     "Another entry with the same name already exists" : "Toinen tietue samalla nimellä on jo olemassa",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Kohdetta \"{oldName}\" ei voitu nimetä uudelleen, koska sitä ei ole enää olemassa",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{newName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
+    "Could not rename \"{oldName}\"" : "Ei voitu nimetä uudelleen \"{oldName}\"",
     "Storage informations" : "Tallennustilan tietoja",
+    "Choose file" : "Valitse tiedosto",
+    "Go to the previous folder" : "Siirry edelliseen kansioon",
     "Open the files app settings" : "Avaa tiedostosovelluksen asetukset",
     "You might not have have permissions to view it, ask the sender to share it" : "Oikeutesi eivät kenties riitä sen katseluun, pyydä lähettäjää jakamaan se",
     "The files is locked" : "Tiedosto on lukittu",
-    "Create new templates folder" : "Luo uusi mallipohjien kansio"
+    "Create new templates folder" : "Luo uusi mallipohjien kansio",
+    "List of favorites files and folders." : "Luettelo suosikkitiedostoista ja -kansioista.",
+    "Text file" : "Tekstitiedosto",
+    "New text file.txt" : "Uusi tekstitiedosto.txt",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Suora linkki kopioitu (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopioi suora linkki (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)"
 },
 "nplurals=2; plural=(n != 1);");
