@@ -1,120 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "Il file non può essere trovato",
-    "Move or copy" : "Sposta o copia",
-    "Download" : "Scarica",
-    "Delete" : "Elimina",
-    "Tags" : "Etichette",
-    "Show list view" : "Mostra la vista elenco",
-    "Show grid view" : "Mostra la visualizzazione griglia",
-    "Home" : "Home",
-    "Close" : "Chiudi",
-    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
-    "This will stop your current uploads." : "Questo fermerà i caricamenti attuali.",
-    "Upload cancelled." : "Caricamento annullato.",
-    "Processing files …" : "Elaborazione file in corso…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
-    "Not enough free space" : "Spazio libero insufficiente",
-    "An unknown error has occurred" : "Si è verificato un errore sconosciuto",
-    "File could not be uploaded" : "Il file non può essere caricato",
-    "Uploading …" : "Caricamento in corso...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Caricamento … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Il caricamento di tale elemento non è supportato",
-    "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
-    "Operation is blocked by access control" : "L'operazione è bloccata dal controllo di accesso",
-    "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
-    "Actions" : "Azioni",
-    "Rename" : "Rinomina",
-    "Move" : "Sposta",
-    "Copy" : "Copia",
-    "Choose target folder" : "Scegli la cartella di destinazione",
-    "Set reminder" : "Imposta promemoria",
-    "Edit locally" : "Modifica localmente",
-    "Open" : "Apri",
-    "Delete file" : "Elimina file",
-    "Delete folder" : "Elimina cartella",
-    "Disconnect storage" : "Disconnetti archiviazione",
-    "Leave this share" : "Abbandona questa condivisione",
-    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
-    "Files" : "File",
-    "Details" : "Dettagli",
-    "Please select tag(s) to add to the selection" : "Seleziona un'etichetta(e) da aggiungere alla selezione",
-    "Apply tag(s) to selection" : "Applica etichetta(e) alla selezione",
-    "Select directory \"{dirName}\"" : "Seleziona cartella \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Seleziona file \"{fileName}\"",
-    "Pending" : "In corso",
-    "Unable to determine date" : "Impossibile determinare la data",
-    "This operation is forbidden" : "Questa operazione è vietata",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
-    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
-    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
-    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
-    "copy" : "copia",
-    "Could not copy \"{file}\", target exists" : "Impossibile copiare \"{file}\", la destinazione esiste già",
-    "Could not copy \"{file}\"" : "Impossibile copiare \"{file}\"",
-    "Copied {origin} inside {destination}" : "Copiato {origin} in {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiati {origin} e {nbfiles} altri file in {destination}",
-    "Failed to redirect to client" : "Reindirizzamento al client non riuscito",
-    "{newName} already exists" : "{newName} esiste già",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
-    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
-    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
-    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
-    "Could not fetch file details \"{file}\"" : "Impossibile recuperare i dettagli del file \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Digita più di due caratteri per cercare in altre cartelle",
-    "Name" : "Nome",
-    "Size" : "Dimensione",
-    "Modified" : "Modificato",
-    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle","%n cartelle"],
-    "_%n file_::_%n files_" : ["%n file","%n file","%n file"],
-    "{dirs} and {files}" : "{dirs} e {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti","inclusi %n nascosti"],
-    "You do not have permission to upload or create files here" : "Non disponi dei permessi per caricare o creare file qui",
-    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso","Caricamento di %n file in corso"],
-    "New" : "Nuovo",
-    "New file/folder menu" : "Nuovo menu file/cartella",
-    "Select file range" : "Seleziona intervallo di file",
-    "{used}%" : "{used}%",
-    "{used} of {quota} used" : "{used} di {quota} utilizzati",
-    "{used} used" : "{used} utilizzati",
-    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
-    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
-    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La cartella di gruppo \"{mountPoint}\" è piena, i file non possono più essere aggiornati o sincronizzati!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'archiviazione esterna \"{mountPoint}\" è piena, i file non possono più essere caricati o sincronizzati!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più caricati o sincronizzati!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La cartella di gruppo \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["verifica \"{filter}\"","verificano \"{filter}\"","verificano \"{filter}\""],
-    "View in folder" : "Visualizza nella cartella",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
-    "Path" : "Percorso",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n byte","%n byte"],
-    "Favorited" : "Preferiti",
-    "Favorite" : "Preferito",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
-    "New folder" : "Nuova cartella",
-    "Create new folder" : "Crea una nuova cartella",
-    "Upload file" : "Carica file",
-    "Recent" : "Recenti",
-    "Not favorited" : "Non preferito",
-    "Remove from favorites" : "Rimuovi dai preferiti",
-    "Add to favorites" : "Aggiungi ai preferiti",
-    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
     "Added to favorites" : "Aggiunto ai preferiti",
     "Removed from favorites" : "Rimosso dai preferiti",
     "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
@@ -154,16 +40,14 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
+    "Files" : "File",
     "A file or folder has been <strong>changed</strong>" : "Un file o una cartella è stato <strong>modificato</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Un file preferito o una cartella è stato <strong>modificato</strong>",
     "Failed to authorize" : "Impossibile dare l'autorizzazione",
     "Invalid folder path" : "Percorso della cartella non valido",
     "Folder not found" : "Cartella non trovata",
+    "No favorites" : "Nessun preferito",
     "Upload (max. %s)" : "Carica (massimo %s)",
-    "Files compatibility" : "Compatibilità di File",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Consenti di limitare i nomi di file per assicurarsi che i file vengano sincronizzati con tutti i client. In modo predefinito, tutti i nomi di file validi su POSIX (es. Linux o macOS) sono consentiti.",
-    "Enforce Windows compatibility" : "Imponi la compatibilità con Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ciò bloccherà i nomi di file non validi sui sistemi Windows, come l'uso di nomi riservati o caratteri speciali. Tuttavia non verrà imposta la compatibilità con le maiuscole/minuscole.",
     "Accept" : "Accetta",
     "Reject" : "Rifiuta",
     "Incoming ownership transfer from {user}" : "Trasferimento di proprietà in ingresso da {user}",
@@ -178,15 +62,21 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Il trasferimento di proprietà di {path} da {user} è completato.",
     "in %s" : "in %s",
     "Transferred from %1$s on %2$s" : "Trasferito da %1$s su %2$s",
+    "Files compatibility" : "Compatibilità di File",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Consenti di limitare i nomi di file per assicurarsi che i file vengano sincronizzati con tutti i client. In modo predefinito, tutti i nomi di file validi su POSIX (es. Linux o macOS) sono consentiti.",
+    "Enforce Windows compatibility" : "Imponi la compatibilità con Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ciò bloccherà i nomi di file non validi sui sistemi Windows, come l'uso di nomi riservati o caratteri speciali. Tuttavia non verrà imposta la compatibilità con le maiuscole/minuscole.",
     "File Management" : "Gestione dei file",
     "Current directory path" : "Percorso della cartella corrente",
+    "Home" : "Home",
+    "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
     "Reload current directory" : "Ricarica la cartella corrente",
     "Go to the \"{dir}\" directory" : "Vai alla cartella \"{dir}\"",
     "Drag and drop files here to upload" : "Trascina i file qui per caricarli",
     "Your have used your space quota and cannot upload files anymore" : "Hai esaurito la tua quota di spazio e non puoi più caricare file",
     "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
-    "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
-    "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
+    "Favorite" : "Preferito",
+    "Back" : "Indietro",
     "Toggle selection for file \"{displayName}\"" : "Attiva/disattiva la selezione per il file \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Attiva/disattiva la selezione per la cartella \"{displayName}\"",
     "File is loading" : "Il file è in caricamento",
@@ -198,29 +88,39 @@ OC.L10N.register(
     "Another entry with the same name already exists." : "Esiste già un'altra voce con lo stesso nome.",
     "Invalid filename." : "Nome di file non valido.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Rinominato \"{oldName}\" in \"{newName}\"",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Impossibile rinominare \"{oldName}\", non esiste più",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{newName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
-    "Could not rename \"{oldName}\"" : "Impossibile rinominare \"{oldName}\"",
+    "Unknown date" : "Data sconosciuta",
+    "Pending" : "In corso",
     "Clear filter" : "Pulisci il filtro",
+    "Modified" : "Modificato",
     "Type" : "Tipo",
     "Active filters" : "Filtri attivi",
     "Remove filter" : "Rimuovi filtro",
     "Total rows summary" : "Riepilogo totale delle righe",
+    "Name" : "Nome",
+    "Size" : "Dimensione",
     "Toggle selection for all files and folders" : "Attiva/disattiva la selezione per tutti i file e le cartelle",
+    "Actions" : "Azioni",
+    "(selected)" : "(selezionato)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" non è riuscita su alcuni elementi",
     "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
+    "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
     "{count} selected" : "{count} selezionati",
     "List of files and folders." : "Lista di file e cartelle.",
+    "You don’t have permission to upload or create files here." : "Non hai l'autorizzazione per caricare o creare file qui.",
+    "You have used your space quota and cannot upload files anymore." : "Hai esaurito la tua quota di spazio e non puoi più caricare file.",
     "Column headers with buttons are sortable." : "Le intestazioni di colonna con pulsanti sono ordinabili.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Questa lista non è stata mostrata completamente per ragioni di prestazioni. I file verranno mostrati durante la navigazione della lista.",
     "File not found" : "File non trovato",
     "Storage information" : "Informazioni di archiviazione",
     "Storage quota" : "Limite di archiviazione",
     "{usedQuotaByte} used" : "{usedQuotaByte} usato",
+    "{used} of {quota} used" : "{used} di {quota} utilizzati",
     "{relative}% used" : "{relative}% usato",
     "Could not refresh storage stats" : "Impossibile aggiornare le statistiche di archiviazione",
     "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
     "Create" : "Crea",
+    "New folder" : "Nuova cartella",
+    "Create new folder" : "Crea una nuova cartella",
     "This name is already in use." : "Questo nome è già utilizzato.",
     "Fill template fields" : "Compila i campi del modello",
     "Submitting fields…" : "Invio dei campi…",
@@ -237,12 +137,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Richiesta di trasferimento della proprietà inviata",
     "Cannot transfer ownership of a file or folder you do not own" : "Impossibile trasferire la proprietà di un file o di una cartella di cui non sei proprietario",
     "Select file or folder to link to" : "Seleziona un file o una cartella da collegare",
-    "Choose file" : "Scegli file",
     "Choose {file}" : "Scegli {file}",
     "Loading current folder" : "Sto caricando la cartella corrente",
+    "Retry" : "Riprova",
     "No files in here" : "Qui non c'è alcun file",
     "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
-    "Go to the previous folder" : "Vai alla cartella precedente",
     "Go back" : "Indietro",
     "Share" : "Condividi",
     "Shared by link" : "Condivisi tramite collegamento",
@@ -250,9 +149,12 @@ OC.L10N.register(
     "Switch to list view" : "Passa alla vista elenco",
     "Switch to grid view" : "Passa alla vista griglia",
     "Upload was cancelled by user" : "Caricamento annullato dall'utente",
+    "Not enough free space" : "Spazio libero insufficiente",
+    "Operation is blocked by access control" : "L'operazione è bloccata dal controllo di accesso",
     "Error during upload: {message}" : "Errore durante il caricamento: {message}",
     "Error during upload, status code {status}" : "Errore durante il caricamento, codice di stato {status}",
     "Unknown error during upload" : "Errore sconosciuto durante il caricamento",
+    "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
     "Filter filenames…" : "Filtra nomi di file…",
     "Views" : "Viste",
     "Files settings" : "Impostazioni File",
@@ -272,8 +174,36 @@ OC.L10N.register(
     "Copy to clipboard" : "Copia negli appunti",
     "Use this address to access your Files via WebDAV" : "Usa questo indirizzo per accedere ai tuoi file con WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se hai abilitato il 2FA, devi creare ed usare una nuova password per l'applicazione facendo clic qui.",
+    "Keyboard shortcuts" : "Scorciatoie da tastiera",
+    "Speed up your Files experience with these quick shortcuts." : "Velocizza la tua esperienza con i File con queste rapide scorciatoie.",
+    "Open the actions menu for a file" : "Aprire il menu delle azioni per un file",
+    "Rename a file" : "Rinominare un file",
+    "Delete a file" : "Eliminare un file",
+    "Favorite or remove a file from favorites" : "Aggiungere ai Preferiti o rimuovere un file dai preferiti",
+    "Manage tags for a file" : "Gestire i tag per un file",
+    "Selection" : "Selezione",
+    "Select all files" : "Seleziona tutti i file",
+    "Deselect all files" : "Deseleziona tutti i file",
+    "Select or deselect a file" : "Seleziona o deseleziona un file",
+    "Select a range of files" : "Seleziona un intervallo di file",
+    "Navigation" : "Navigazione",
+    "Navigate to the parent folder" : "Passare alla cartella padre",
+    "Navigate to the file above" : "Vai al file sopra",
+    "Navigate to the file below" : "Vai al file qui sotto",
+    "Navigate to the file on the left (in grid mode)" : "Navigare nel file a sinistra (in modalità griglia)",
+    "Navigate to the file on the right (in grid mode)" : "Navigare nel file a destra (in modalità griglia)",
+    "View" : "Visualizza",
+    "Toggle the grid view" : "Attiva la vista a griglia",
+    "Open the sidebar for a file" : "Aprire la barra laterale per un file",
+    "Show those shortcuts" : "Mostra quelle scorciatoie",
     "Clipboard is not available" : "Appunti non disponibili",
     "WebDAV URL copied to clipboard" : "L'URL WebDAV è stato copiato negli appunti",
+    "Owner" : "Proprietario",
+    "Remove from favorites" : "Rimuovi dai preferiti",
+    "Add to favorites" : "Aggiungi ai preferiti",
+    "Tags" : "Etichette",
+    "You" : "Tu",
+    "Shared multiple times with different people" : "Condiviso più volte con diverse persone",
     "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
     "Error while loading the file data" : "Errore durante il caricamento del file di dati",
     "Pick a template for {name}" : "Scegli un modello per {name}",
@@ -282,22 +212,29 @@ OC.L10N.register(
     "Blank" : "Vuoto",
     "Unable to create new file from template" : "Impossibile creare un nuovo file dal modello",
     "Deletion cancelled" : "Eliminazione annullata",
+    "Leave this share" : "Abbandona questa condivisione",
+    "Leave these shares" : "Abbandona queste condivisioni",
+    "Disconnect storage" : "Disconnetti archiviazione",
+    "Disconnect storages" : "Disconnetti il supporto di archiviazione",
     "Delete permanently" : "Elimina permanentemente",
     "Delete and unshare" : "Elimina e annulla la condivisione",
-    "Leave these shares" : "Abbandona queste condivisioni",
-    "Disconnect storages" : "Disconnetti il supporto di archiviazione",
+    "Delete file" : "Elimina file",
     "Delete files" : "Elimina i file",
+    "Delete folder" : "Elimina cartella",
     "Delete folders" : "Elimina la cartella",
+    "Delete" : "Elimina",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Stai per eliminare permanentemente {count} elemento","Stai per eliminare permanentemente {count} elementi","Stai per eliminare permanentemente {count} elementi"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Stai per eliminare {count} elemento","Stai per eliminare {count} elementi","Stai per eliminare {count} elementi"],
     "Confirm deletion" : "Conferma l'eliminazione",
     "Cancel" : "Annulla",
     "Edit file locally" : "Modifica il file localmente",
-    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "I file dovrebbe ora aprirsi in locale. Se non succede, assicurati che il client desktop sia installato nel tuo sistema.",
-    "Retry local edit" : "Riprova modifica in locale",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Il file dovrebbe ora aprirsi sul tuo dispositivo. In caso contrario, controlla di aver installato l'app desktop.",
+    "Retry and close" : "Riprova e chiudi",
     "Edit online" : "Modifica online",
-    "Destination is not a folder" : "La destinazione non è una cartella",
-    "This file/folder is already in that directory" : "Questo file/cartella è già in quella cartella",
+    "Failed to redirect to client" : "Reindirizzamento al client non riuscito",
+    "Edit locally" : "Modifica localmente",
+    "Moving \"{source}\" to \"{destination}\" …" : "Sposta \"{source}\" in \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copia \"{source}\" in \"{destination}\" …",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non puoi spostare un file/cartella in se stesso o in una sottocartella di se stesso",
     "(copy)" : "(copia)",
     "(copy %n)" : "(copia %n)",
@@ -307,13 +244,18 @@ OC.L10N.register(
     "The file does not exist anymore" : "Il file non esiste più",
     "Choose destination" : "Scegli la destinazione",
     "Copy to {target}" : "Copia in {target}",
+    "Copy" : "Copia",
     "Move to {target}" : "Sposta in {target}",
+    "Move" : "Sposta",
     "Move or copy operation failed" : "Operazione di spostamento o copia fallita",
+    "Move or copy" : "Sposta o copia",
     "Cancelled move or copy of \"{filename}\"." : "Spostamento o copia di \"{filename}\" annullato.",
     "Cancelled move or copy operation" : "Operazione di spostamento o copia annullata",
     "Open folder {displayName}" : "Apri la cartella {displayName}",
     "Open in Files" : "Apri in File",
+    "Rename" : "Rinomina",
     "Open details" : "Apri i dettagli",
+    "View in folder" : "Visualizza nella cartella",
     "Today" : "Ogg",
     "Last 7 days" : "Ultimi 7 giorni",
     "Last 30 days" : "Ultimi 30 giorni",
@@ -348,6 +290,17 @@ OC.L10N.register(
     "Files moved successfully" : "File spostati correttamente",
     "Conflicts resolution skipped" : "Risoluzione dei conflitti saltata",
     "Upload cancelled" : "Caricamento annullato",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Aggiungere l'estensione del file \"{new}\" potrebbe rendere il file illeggibile.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Rimuovendo dell'estensione del file \"{old}\" potrebbe rendere il file illeggibile.",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Modificando l'estensione del file da \"{old}\" a\"{new}\" potrebbe rendere il file illeggibile.",
+    "Change file extension" : "Cambia estensione file",
+    "Keep {oldextension}" : "Tieni {oldextension}",
+    "Use {newextension}" : "Usa {newextension}",
+    "Remove extension" : "Rimuovi estensione",
+    "This operation is forbidden" : "Questa operazione è vietata",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
+    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
+    "Unexpected error: {error}" : "Errore imprevisto: {error}",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartelle","{folderCount} cartelle"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} file","{fileCount} file"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file e {folderCount} cartella","1 file e {folderCount} cartelle","1 file e {folderCount} cartelle"],
@@ -358,7 +311,7 @@ OC.L10N.register(
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" è un nome riservato e non consentito per i nomi di file.",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" non è un tipo di file consentito.",
     "Filenames must not end with \"{extension}\"." : "I nomi di file non possono terminare con \"{extension}\".",
-    "List of favorites files and folders." : "Lista di file e cartelle preferiti.",
+    "List of favorite files and folders." : "Elenco dei file e delle cartelle preferiti.",
     "No favorites yet" : "Nessun preferito ancora",
     "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
     "All files" : "Tutti i file",
@@ -368,17 +321,95 @@ OC.L10N.register(
     "List of your files and folders that are not shared." : "Elenco dei file e delle cartelle che non sono condivisi.",
     "No personal files found" : "Nessun file personale trovato",
     "Files that are not shared will show up here." : "I file che non vengono condivisi verranno visualizzati qui.",
+    "Recent" : "Recenti",
     "List of recently modified files and folders." : "Lista di file e cartelle modificati di recente.",
     "No recently modified files" : "Nessun file modificato di recente",
     "Files and folders you recently modified will show up here." : "I file e le cartelle che hai modificato di recente saranno mostrati qui.",
+    "You do not have permission to upload or create files here" : "Non disponi dei permessi per caricare o creare file qui",
     "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
     "Select all" : "Seleziona tutto",
     "Upload too large" : "Caricamento troppo grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
-    "Text file" : "File di testo",
-    "New text file.txt" : "Nuovo file di testo.txt",
+    "File could not be found" : "Il file non può essere trovato",
+    "Download" : "Scarica",
+    "Show list view" : "Mostra la vista elenco",
+    "Show grid view" : "Mostra la visualizzazione griglia",
+    "Close" : "Chiudi",
+    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
+    "This will stop your current uploads." : "Questo fermerà i caricamenti attuali.",
+    "Upload cancelled." : "Caricamento annullato.",
+    "Processing files …" : "Elaborazione file in corso…",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
+    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
+    "An unknown error has occurred" : "Si è verificato un errore sconosciuto",
+    "File could not be uploaded" : "Il file non può essere caricato",
+    "Uploading …" : "Caricamento in corso...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Caricamento … ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Il caricamento di tale elemento non è supportato",
+    "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
+    "Choose target folder" : "Scegli la cartella di destinazione",
+    "Set reminder" : "Imposta promemoria",
+    "Open" : "Apri",
+    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
+    "Details" : "Dettagli",
+    "Please select tag(s) to add to the selection" : "Seleziona un'etichetta(e) da aggiungere alla selezione",
+    "Apply tag(s) to selection" : "Applica etichetta(e) alla selezione",
+    "Select directory \"{dirName}\"" : "Seleziona cartella \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Seleziona file \"{fileName}\"",
+    "Unable to determine date" : "Impossibile determinare la data",
+    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
+    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
+    "copy" : "copia",
+    "Could not copy \"{file}\", target exists" : "Impossibile copiare \"{file}\", la destinazione esiste già",
+    "Could not copy \"{file}\"" : "Impossibile copiare \"{file}\"",
+    "Copied {origin} inside {destination}" : "Copiato {origin} in {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiati {origin} e {nbfiles} altri file in {destination}",
+    "{newName} already exists" : "{newName} esiste già",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
+    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
+    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
+    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
+    "Could not fetch file details \"{file}\"" : "Impossibile recuperare i dettagli del file \"{file}\"",
+    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "Digita più di due caratteri per cercare in altre cartelle",
+    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle","%n cartelle"],
+    "_%n file_::_%n files_" : ["%n file","%n file","%n file"],
+    "{dirs} and {files}" : "{dirs} e {files}",
+    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti","inclusi %n nascosti"],
+    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso","Caricamento di %n file in corso"],
+    "New" : "Nuovo",
+    "New file/folder menu" : "Nuovo menu file/cartella",
+    "Select file range" : "Seleziona intervallo di file",
+    "{used}%" : "{used}%",
+    "{used} used" : "{used} utilizzati",
+    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
+    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
+    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La cartella di gruppo \"{mountPoint}\" è piena, i file non possono più essere aggiornati o sincronizzati!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'archiviazione esterna \"{mountPoint}\" è piena, i file non possono più essere caricati o sincronizzati!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più caricati o sincronizzati!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La cartella di gruppo \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["verifica \"{filter}\"","verificano \"{filter}\"","verificano \"{filter}\""],
     "Direct link was copied (only works for users who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
+    "Path" : "Percorso",
+    "_%n byte_::_%n bytes_" : ["%n byte","%n byte","%n byte"],
+    "Favorited" : "Preferiti",
     "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
+    "Upload file" : "Carica file",
+    "Not favorited" : "Non preferito",
+    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
     "\"remote user\"" : "\"utente remoto\"",
     "{newName} already exists." : "{newName} esiste già.",
     "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" non è consentito in un nome di file.",
@@ -387,11 +418,24 @@ OC.L10N.register(
     "Filenames must not end with \"{segment}\"." : "I nomi di file non possono terminare con \"{segment}\".",
     "Name cannot be empty" : "Il nome non può essere vuoto",
     "Another entry with the same name already exists" : "Esiste già un'altra voce con lo stesso nome",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Impossibile rinominare \"{oldName}\", non esiste più",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{newName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
+    "Could not rename \"{oldName}\"" : "Impossibile rinominare \"{oldName}\"",
     "Storage informations" : "Informazioni di archiviazione",
+    "Choose file" : "Scegli file",
+    "Go to the previous folder" : "Vai alla cartella precedente",
     "Open the files app settings" : "Apri le impostazioni dell'applicazione File",
     "You might not have have permissions to view it, ask the sender to share it" : "Potresti non avere i permessi per visualizzarlo, chiedi al mittente di condividerlo",
     "The files is locked" : "Il file è bloccato",
     "Create new templates folder" : "Crea una nuova cartella dei modelli",
-    "Toggle %1$s sublist" : "Passa alla sottolista %1$s"
+    "List of favorites files and folders." : "Lista di file e cartelle preferiti.",
+    "Toggle %1$s sublist" : "Passa alla sottolista %1$s",
+    "Text file" : "File di testo",
+    "New text file.txt" : "Nuovo file di testo.txt",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
+    "Favored" : "Preferito",
+    "Favor" : "Preferiti",
+    "Not favored" : "Non preferito"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
