@@ -1,120 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "Filen ble ikke funnet",
-    "Move or copy" : "Flytt eller kopier",
-    "Download" : "Last ned",
-    "Delete" : "Slett",
-    "Tags" : "Merkelapper",
-    "Show list view" : "Vis listevisning",
-    "Show grid view" : "Vis rutenett-visning",
-    "Home" : "Hjem",
-    "Close" : "Lukk",
-    "Could not create folder \"{dir}\"" : "Kunne ikke å opprette mappe \"{dir}\"",
-    "This will stop your current uploads." : "Dette vil stoppe dine nåværende opplastinger.",
-    "Upload cancelled." : "Opplasting avbrutt.",
-    "Processing files …" : "Prosesserer filer…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 Byte",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp {size1} men bare {size2} er ledig",
-    "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
-    "Not enough free space" : "Ikke nok ledig diskplass",
-    "An unknown error has occurred" : "En ukjent feil oppsto",
-    "File could not be uploaded" : "Fil kunne ikke lastes opp",
-    "Uploading …" : "Laster opp…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Laster opp... ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Opplastning av det elementet er ikke støttet",
-    "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
-    "Operation is blocked by access control" : "Operasjonen er blokkert på grunn av tilgangskontroll",
-    "Error when assembling chunks, status code {status}" : "Feil under sammenkobling av biter, statuskode {status}",
-    "Actions" : "Handlinger",
-    "Rename" : "Gi nytt navn",
-    "Move" : "Flytt",
-    "Copy" : "Kopier",
-    "Choose target folder" : "Velg målmappe",
-    "Set reminder" : "Angi påminnelse",
-    "Edit locally" : "Rediger lokalt",
-    "Open" : "Åpne",
-    "Delete file" : "Slett fil",
-    "Delete folder" : "Slett mappe",
-    "Disconnect storage" : "Koble fra lager",
-    "Leave this share" : "Forlat denne delingen",
-    "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
-    "Files" : "Filer",
-    "Details" : "Detaljer",
-    "Please select tag(s) to add to the selection" : "Velg merkelapper(er) for å legge til utvalget",
-    "Apply tag(s) to selection" : "Bruk merkelapp(er) på utvalget",
-    "Select directory \"{dirName}\"" : "Velg mappe \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Velg fil \"{fileName}\"",
-    "Pending" : "Venter",
-    "Unable to determine date" : "Kan ikke fastslå datoen",
-    "This operation is forbidden" : "Operasjonen er forbudt",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
-    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
-    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
-    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
-    "copy" : "kopier",
-    "Could not copy \"{file}\", target exists" : "Klarte ikke å kopiere \"{file}\", målfilen finnes",
-    "Could not copy \"{file}\"" : "Klarte ikke å kopiere \"{file}\"",
-    "Copied {origin} inside {destination}" : "Kopierte {origin} i {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierte {origin} og {nbfiles} andre filer i {destination}",
-    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
-    "{newName} already exists" : "{newName} finnes allerede",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
-    "Could not rename \"{fileName}\"" : "Klarte ikke å gi \"{fileName}\" nytt navn",
-    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
-    "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
-    "Could not fetch file details \"{file}\"" : "Kunne ikke hente fildetaljene \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søkeresultater i andre mapper etter {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Tast inn mer enn to tegn for å lete i andre mapper",
-    "Name" : "Navn",
-    "Size" : "Størrelse",
-    "Modified" : "Endret",
-    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
-    "_%n file_::_%n files_" : ["%n fil","%n filer"],
-    "{dirs} and {files}" : "{dirs} og {files}",
-    "_including %n hidden_::_including %n hidden_" : ["Inkludert %n skjult","Inkludert %n skjulte"],
-    "You do not have permission to upload or create files here" : "Du har ikke tilgang til å laste opp eller opprette filer her",
-    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
-    "New" : "Ny",
-    "New file/folder menu" : "Ny fil/mappe-meny",
-    "Select file range" : "Velg filutvalg",
-    "{used}%" : "{used}%",
-    "{used} of {quota} used" : "{used} av {quota} brukt",
-    "{used} used" : "{used} brukt",
-    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
-    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
-    "\"/\" is not allowed inside a file name." : "\"/\" tillates ikke i et filnavn.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lagringen av {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppemappen \"{mountPoint}\" er full, filer kan ikke oppdateres eller synkroniseres lenger!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ekstern lagring \"{mountPoint}\" er full, filer kan ikke oppdateres eller synkroniseres lenger!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Lagringen din er full, filer kan ikke oppdateres eller synkroniseres lenger!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppemappen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Den eksterne lagringsplassen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Din lagringsplass er nesten full ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Treffer \"{filter}\"","Treff \"{filter}\""],
-    "View in folder" : "Vis i mappe",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Direkte lenke ble kopiert (fungerer bare for personer som har tilgang til denne filen / mappen)",
-    "Path" : "Sti",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
-    "Favorited" : "Favorisert",
-    "Favorite" : "Gjør til favoritt",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopier direkte lenke (fungerer bare for personer som har tilgang til denne filen / mappen)",
-    "New folder" : "Ny mappe",
-    "Create new folder" : "Opprett ny mappe",
-    "Upload file" : "Last opp fil",
-    "Recent" : "Nylig",
-    "Not favorited" : "Ikke i favoritter",
-    "Remove from favorites" : "Fjern fra favoritter",
-    "Add to favorites" : "Legg til i favoritter",
-    "An error occurred while trying to update the tags" : "En feil oppsto under oppdatering av merkelappene",
     "Added to favorites" : "Lagt til i favoritter",
     "Removed from favorites" : "Fjernet fra favoritter",
     "You added {file} to your favorites" : "Du la til {file} i dine favoritter",
@@ -154,16 +40,14 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Du flyttet {oldfile} til {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} flyttet {oldfile} til {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har blitt lagt til eller fjernet fra dine <strong>favoritter</strong>",
+    "Files" : "Filer",
     "A file or folder has been <strong>changed</strong>" : "En fil eller mappe ble <strong>endret</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "En favoritt-fil eller mappe har blitt <strong>endret</strong>",
     "Failed to authorize" : "Autorisering feilet",
     "Invalid folder path" : "Ugyldig mappebane",
     "Folder not found" : "Mappe ikke funnet",
+    "No favorites" : "Ingen favoritter",
     "Upload (max. %s)" : "Opplasting (maks %s)",
-    "Files compatibility" : "Kompatibilitet med filer",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillat å begrense filnavn for å sikre at filer kan synkroniseres med alle klienter. Som standard er alle filnavn  gyldige på POSIX (f.eks. Linux eller macOS) tillatt.",
-    "Enforce Windows compatibility" : "Håndhev Windows-kompatibilitet",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dette vil blokkere filnavn som ikke er gyldige på Windows-systemer, for eksempel å bruke reserverte navn eller spesialtegn. Men dette vil ikke håndheve kompatibiliteten til store og små bokstaver.",
     "Accept" : "Aksepter",
     "Reject" : "Avvis",
     "Incoming ownership transfer from {user}" : "Ny eierskapsoverføring fra {user}",
@@ -178,15 +62,21 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Eierskapsoverføring av {path} fra {user} er ferdig.",
     "in %s" : "om %s",
     "Transferred from %1$s on %2$s" : "Overført fra %1$s på %2$s",
+    "Files compatibility" : "Kompatibilitet med filer",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillat å begrense filnavn for å sikre at filer kan synkroniseres med alle klienter. Som standard er alle filnavn  gyldige på POSIX (f.eks. Linux eller macOS) tillatt.",
+    "Enforce Windows compatibility" : "Håndhev Windows-kompatibilitet",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dette vil blokkere filnavn som ikke er gyldige på Windows-systemer, for eksempel å bruke reserverte navn eller spesialtegn. Men dette vil ikke håndheve kompatibiliteten til store og små bokstaver.",
     "File Management" : "Filbehandling",
     "Current directory path" : "Gjeldende katalogsti",
+    "Home" : "Hjem",
+    "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
     "Reload current directory" : "Last inn gjeldende katalog på nytt",
     "Go to the \"{dir}\" directory" : "Gå til \"{dir}\"-katalogen",
     "Drag and drop files here to upload" : "Dra og slipp filer her for å laste opp",
     "Your have used your space quota and cannot upload files anymore" : "Du har brukt opp plasskvoten og kan ikke laste opp filer lenger",
     "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
-    "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
+    "Favorite" : "Gjør til favoritt",
+    "Back" : "Tilbake",
     "Toggle selection for file \"{displayName}\"" : "Veksle valg for fil \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Veksle valg for mappe \"{displayName}\"",
     "File is loading" : "Filen lastes inn",
@@ -198,17 +88,22 @@ OC.L10N.register(
     "Another entry with the same name already exists." : "En annen oppføring med samme navnet finnes allerede.",
     "Invalid filename." : "Ugyldig filnavn.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøpte \"{oldName}\" tl \"{newName}\"",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøpe \"{oldName}\", den finnes ikke lenger",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{newName}\" er allerede brukt i mappen \"{dir}\". Velg et annet navn.",
-    "Could not rename \"{oldName}\"" : "Kunne ikke omdøpe \"{oldName}\"",
+    "Unknown date" : "Ukjent dato",
+    "Pending" : "Venter",
     "Clear filter" : "Tøm filter",
+    "Modified" : "Endret",
     "Type" : "Type",
     "Active filters" : "Aktivt filter",
     "Remove filter" : "Fjern filter",
     "Total rows summary" : "Sammendrag av totalrader",
+    "Name" : "Navn",
+    "Size" : "Størrelse",
     "Toggle selection for all files and folders" : "Veksle valg for alle filer og mapper",
+    "Actions" : "Handlinger",
+    "(selected)" : "(valgt)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" feilet på noen elementer",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massehandling utført",
+    "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
     "{count} selected" : "{count} valgt",
     "List of files and folders." : "Liste over filer og mapper.",
     "Column headers with buttons are sortable." : "Kolonneoverskrifter med knapper kan sorteres.",
@@ -217,10 +112,13 @@ OC.L10N.register(
     "Storage information" : "Informasjon om lagring",
     "Storage quota" : "Lagringskvote",
     "{usedQuotaByte} used" : "{usedQuotaByte} brukt",
+    "{used} of {quota} used" : "{used} av {quota} brukt",
     "{relative}% used" : "{relative}% brukt",
     "Could not refresh storage stats" : "Kunne ikke oppdatere lagringsstatistikk",
     "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
     "Create" : "Opprett",
+    "New folder" : "Ny mappe",
+    "Create new folder" : "Opprett ny mappe",
     "This name is already in use." : "Navnet er allerede i bruk.",
     "Fill template fields" : "Fyll ut malfelt",
     "Submitting fields…" : "Sender inn felt...",
@@ -237,12 +135,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Forespørsel om overføring av eierskap er sendt",
     "Cannot transfer ownership of a file or folder you do not own" : "Kan ikke overføre eierskap til en fil eller mappe du ikke eier",
     "Select file or folder to link to" : "Velg fil eller mappe å koble til",
-    "Choose file" : "Velg fil",
     "Choose {file}" : "Choose {file}",
     "Loading current folder" : "Laster gjeldende mappe",
+    "Retry" : "Prøv igjen",
     "No files in here" : "Ingen filer",
     "Upload some content or sync with your devices!" : "Last opp innhold eller synkroniser med enhetene dine!",
-    "Go to the previous folder" : "Gå fil forrige mappe",
     "Go back" : "Gå tilbake",
     "Share" : "Del med andre",
     "Shared by link" : "Delt med lenke",
@@ -250,9 +147,12 @@ OC.L10N.register(
     "Switch to list view" : "Bytt til listevisning",
     "Switch to grid view" : "Bytt til rutevisning",
     "Upload was cancelled by user" : "Opplasting ble avbrutt av bruker",
+    "Not enough free space" : "Ikke nok ledig diskplass",
+    "Operation is blocked by access control" : "Operasjonen er blokkert på grunn av tilgangskontroll",
     "Error during upload: {message}" : "Feil under opplasting: {message}",
     "Error during upload, status code {status}" : "Feil under opplasting, statuskode {status}",
     "Unknown error during upload" : "Ukjent feil under opplasting",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
     "Filter filenames…" : "Filtrer filnavn...",
     "Views" : "Visninger",
     "Files settings" : "Filinnstillinger",
@@ -272,8 +172,18 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiert til utklippstavlen",
     "Use this address to access your Files via WebDAV" : "Bruk denne adressen for tilgang til filene dine via WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktivert 2FA, må du opprette og bruke et nytt app-passord ved å klikke her.",
+    "Keyboard shortcuts" : "Tastatursnarveier",
+    "Selection" : "Valg",
+    "Navigation" : "Navigasjon",
+    "View" : "Vis",
     "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
     "WebDAV URL copied to clipboard" : "WebDAV-URL kopiert til utklippstavlen",
+    "Owner" : "Eier",
+    "Remove from favorites" : "Fjern fra favoritter",
+    "Add to favorites" : "Legg til i favoritter",
+    "Tags" : "Merkelapper",
+    "You" : "Du",
+    "Shared multiple times with different people" : "Del flere ganger med forskjellige personer",
     "Unable to change the favourite state of the file" : "Kan ikke endre favorittstatus til filen",
     "Error while loading the file data" : "Feil ved lasting av fildata",
     "Pick a template for {name}" : "Velg en mal for {name}",
@@ -282,22 +192,27 @@ OC.L10N.register(
     "Blank" : "Tom",
     "Unable to create new file from template" : "Kan ikke opprette ny fil fra malen",
     "Deletion cancelled" : "Sletting avbrutt",
+    "Leave this share" : "Forlat denne delingen",
+    "Leave these shares" : "Forlat disse delingene",
+    "Disconnect storage" : "Koble fra lager",
+    "Disconnect storages" : "Koble fra lagringer",
     "Delete permanently" : "Slett for godt",
     "Delete and unshare" : "Slett og opphev deling",
-    "Leave these shares" : "Forlat disse delingene",
-    "Disconnect storages" : "Koble fra lagringer",
+    "Delete file" : "Slett fil",
     "Delete files" : "Slett filer",
+    "Delete folder" : "Slett mappe",
     "Delete folders" : "Slett mapper",
+    "Delete" : "Slett",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Du er i ferd med å slette permanent {count} element","Du er i ferd med å slette permanent {count} elementer"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Du er i ferd med å slette {count} element","Du er i ferd med å slette {count} elementer"],
     "Confirm deletion" : "Bekreft sletting",
     "Cancel" : "Avbryt",
     "Edit file locally" : "Rediger fil lokalt",
-    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Filen skal nå åpnes lokalt. Hvis du ikke ser at dette skjer, må du kontrollere at skrivebordsklienten er installert på systemet.",
-    "Retry local edit" : "Prøv lokal redigering på nytt",
     "Edit online" : "Rediger på nett",
-    "Destination is not a folder" : "Målplassering er ikke en mappe",
-    "This file/folder is already in that directory" : "Denne filen/mappen er allerede i den katalogen",
+    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
+    "Edit locally" : "Rediger lokalt",
+    "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan ikke flytte en fil/mappe til seg selv eller til en undermappe av seg selv",
     "(copy)" : "(kopier)",
     "(copy %n)" : "(kopier %n)",
@@ -307,13 +222,18 @@ OC.L10N.register(
     "The file does not exist anymore" : "Filen finnes ikke lenger",
     "Choose destination" : "Velg målplassering",
     "Copy to {target}" : "Copy to {target}",
+    "Copy" : "Kopier",
     "Move to {target}" : "Move to {target}",
+    "Move" : "Flytt",
     "Move or copy operation failed" : "Flytte- eller kopieringsoperason feilet",
+    "Move or copy" : "Flytt eller kopier",
     "Cancelled move or copy of \"{filename}\"." : "Kansellert flytte- eller kopieroperasjon av \"{filename}\"",
     "Cancelled move or copy operation" : "Kansellert flytte- eller kopieroperasjon",
     "Open folder {displayName}" : "Åpne mappe {displayName}",
     "Open in Files" : "Åpne i Filer",
+    "Rename" : "Gi nytt navn",
     "Open details" : "Åpne detaljer",
+    "View in folder" : "Vis i mappe",
     "Today" : "I dag",
     "Last 7 days" : "Siste 7 dager",
     "Last 30 days" : "Siste 30 dager",
@@ -348,6 +268,9 @@ OC.L10N.register(
     "Files moved successfully" : "Filer ble flyttet",
     "Conflicts resolution skipped" : "Konfliktløsning hoppet over",
     "Upload cancelled" : "Opplasting avbrutt",
+    "This operation is forbidden" : "Operasjonen er forbudt",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
+    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappe","{folderCount} mapper"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil og {folderCount} mappe","1 fil og {folderCount} mapper"],
@@ -358,7 +281,7 @@ OC.L10N.register(
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" er et reservert navn og ikke tillatt for filnavn.",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" er ikke en tillatt filtype.",
     "Filenames must not end with \"{extension}\"." : "Filnavn må ikke slutte med \"{extension}\".",
-    "List of favorites files and folders." : "Liste over favorittfiler og -mapper.",
+    "List of favorite files and folders." : "Liste over favorittfiler og mapper.",
     "No favorites yet" : "Ingen favoritter enda",
     "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
     "All files" : "Alle filer",
@@ -368,17 +291,95 @@ OC.L10N.register(
     "List of your files and folders that are not shared." : "Liste over dine filer og mapper som ikke er delt.",
     "No personal files found" : "Ingen personlige filer funnet",
     "Files that are not shared will show up here." : "Filer som ikke er delt vil vises her.",
+    "Recent" : "Nylig",
     "List of recently modified files and folders." : "Liste over nylig endrede filer og mapper.",
     "No recently modified files" : "Ingen nylig endrede filer",
     "Files and folders you recently modified will show up here." : "Filer og mapper du nylig har endret, vises her.",
+    "You do not have permission to upload or create files here" : "Du har ikke tilgang til å laste opp eller opprette filer her",
     "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
     "Select all" : "Velg alle",
     "Upload too large" : "Filen er for stor",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
-    "Text file" : "Tekstfil",
-    "New text file.txt" : "Ny tekstfil.txt",
+    "File could not be found" : "Filen ble ikke funnet",
+    "Download" : "Last ned",
+    "Show list view" : "Vis listevisning",
+    "Show grid view" : "Vis rutenett-visning",
+    "Close" : "Lukk",
+    "Could not create folder \"{dir}\"" : "Kunne ikke å opprette mappe \"{dir}\"",
+    "This will stop your current uploads." : "Dette vil stoppe dine nåværende opplastinger.",
+    "Upload cancelled." : "Opplasting avbrutt.",
+    "Processing files …" : "Prosesserer filer…",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 Byte",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp {size1} men bare {size2} er ledig",
+    "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
+    "An unknown error has occurred" : "En ukjent feil oppsto",
+    "File could not be uploaded" : "Fil kunne ikke lastes opp",
+    "Uploading …" : "Laster opp…",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Laster opp... ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Opplastning av det elementet er ikke støttet",
+    "Error when assembling chunks, status code {status}" : "Feil under sammenkobling av biter, statuskode {status}",
+    "Choose target folder" : "Velg målmappe",
+    "Set reminder" : "Angi påminnelse",
+    "Open" : "Åpne",
+    "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
+    "Details" : "Detaljer",
+    "Please select tag(s) to add to the selection" : "Velg merkelapper(er) for å legge til utvalget",
+    "Apply tag(s) to selection" : "Bruk merkelapp(er) på utvalget",
+    "Select directory \"{dirName}\"" : "Velg mappe \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Velg fil \"{fileName}\"",
+    "Unable to determine date" : "Kan ikke fastslå datoen",
+    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
+    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
+    "copy" : "kopier",
+    "Could not copy \"{file}\", target exists" : "Klarte ikke å kopiere \"{file}\", målfilen finnes",
+    "Could not copy \"{file}\"" : "Klarte ikke å kopiere \"{file}\"",
+    "Copied {origin} inside {destination}" : "Kopierte {origin} i {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierte {origin} og {nbfiles} andre filer i {destination}",
+    "{newName} already exists" : "{newName} finnes allerede",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
+    "Could not rename \"{fileName}\"" : "Klarte ikke å gi \"{fileName}\" nytt navn",
+    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
+    "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
+    "Could not fetch file details \"{file}\"" : "Kunne ikke hente fildetaljene \"{file}\"",
+    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søkeresultater i andre mapper etter {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "Tast inn mer enn to tegn for å lete i andre mapper",
+    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
+    "_%n file_::_%n files_" : ["%n fil","%n filer"],
+    "{dirs} and {files}" : "{dirs} og {files}",
+    "_including %n hidden_::_including %n hidden_" : ["Inkludert %n skjult","Inkludert %n skjulte"],
+    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
+    "New" : "Ny",
+    "New file/folder menu" : "Ny fil/mappe-meny",
+    "Select file range" : "Velg filutvalg",
+    "{used}%" : "{used}%",
+    "{used} used" : "{used} brukt",
+    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
+    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
+    "\"/\" is not allowed inside a file name." : "\"/\" tillates ikke i et filnavn.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lagringen av {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppemappen \"{mountPoint}\" er full, filer kan ikke oppdateres eller synkroniseres lenger!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ekstern lagring \"{mountPoint}\" er full, filer kan ikke oppdateres eller synkroniseres lenger!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Lagringen din er full, filer kan ikke oppdateres eller synkroniseres lenger!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppemappen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Den eksterne lagringsplassen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Din lagringsplass er nesten full ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Treffer \"{filter}\"","Treff \"{filter}\""],
     "Direct link was copied (only works for users who have access to this file/folder)" : "Direktelenke ble kopiert (fungerer bare for brukere som har tilgang til denne filen/mappen)",
+    "Path" : "Sti",
+    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
+    "Favorited" : "Favorisert",
     "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direktelenke (fungerer bare for brukere som har tilgang til denne filen/mappen)",
+    "Upload file" : "Last opp fil",
+    "Not favorited" : "Ikke i favoritter",
+    "An error occurred while trying to update the tags" : "En feil oppsto under oppdatering av merkelappene",
     "\"remote user\"" : "\"ekstern bruker\"",
     "{newName} already exists." : "{newName} finnes allerede.",
     "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" er ikke tillatt i et filnavn.",
@@ -387,11 +388,24 @@ OC.L10N.register(
     "Filenames must not end with \"{segment}\"." : "Filnavn må ikke slutte med \"{segment}\".",
     "Name cannot be empty" : "Navn kan ikke være tom",
     "Another entry with the same name already exists" : "En annen oppføring med samme navnet finnes allerede",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøpe \"{oldName}\", den finnes ikke lenger",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{newName}\" er allerede brukt i mappen \"{dir}\". Velg et annet navn.",
+    "Could not rename \"{oldName}\"" : "Kunne ikke omdøpe \"{oldName}\"",
     "Storage informations" : "Informasjon om lagring",
+    "Choose file" : "Velg fil",
+    "Go to the previous folder" : "Gå fil forrige mappe",
     "Open the files app settings" : "Åpne Filer-appens innstillinger",
     "You might not have have permissions to view it, ask the sender to share it" : "Du har kanskje ikke tillatelse til å se den, be avsenderen om å dele den",
     "The files is locked" : "Filene er låst",
     "Create new templates folder" : "Opprett ny malermappe",
-    "Toggle %1$s sublist" : "Veksle %1$s underliste"
+    "List of favorites files and folders." : "Liste over favorittfiler og -mapper.",
+    "Toggle %1$s sublist" : "Veksle %1$s underliste",
+    "Text file" : "Tekstfil",
+    "New text file.txt" : "Ny tekstfil.txt",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direkte lenke ble kopiert (fungerer bare for personer som har tilgang til denne filen / mappen)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopier direkte lenke (fungerer bare for personer som har tilgang til denne filen / mappen)",
+    "Favored" : "Favorittlagt",
+    "Favor" : "Favoritt",
+    "Not favored" : "Ikke favorittlagt"
 },
 "nplurals=2; plural=(n != 1);");
