@@ -99,7 +99,6 @@ OC.L10N.register(
     "Personal info" : "פרטים אישיים",
     "Mobile & desktop" : "נייד ושולחן עבודה",
     "Email server" : "שרת דואר אלקטרוני",
-    "Security & setup warnings" : "הזהרות אבטחה והתקנה",
     "Background jobs" : "משימות רקע",
     "Unlimited" : "ללא הגבלה",
     "Verifying" : "מתבצע אימות",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "הופעלה תצורה לקריאה בלבד. מצב זה מונע את הגדרת חלק מההגדרות דרך מנשק דפדפן. יתרה מכך, יש להפוך את הקובץ למורשה לכתיבה ידנית בכל עדכון מחדש.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "מסד הנתונים שלך לא עובד עם רמת הפרדת פעולות של „READ COMMITTED” . מצב כזה יכול לגרום לבעיות כאשר מספר פעולות רצות במקביל.",
     "Nextcloud settings" : "הגדרות Nextcloud",
+    "Enable" : "הפעלה",
     "None" : "כלום",
     "Allow apps to use the Share API" : "לאפשר ליישום להשתמש ב־API השיתוף",
     "Allow resharing" : "לאפשר שיתוף מחדש",
@@ -122,7 +122,6 @@ OC.L10N.register(
     "Allow public uploads" : "אפשר העלאות ציבוריות",
     "Always ask for a password" : "תמיד לבקש ססמה",
     "Enforce password protection" : "חייב הגנת סיסמא",
-    "Set default expiration date for shares" : "הגדרת תאריך תפוגה כבררת מחדל לשיתופים",
     "Enforce expiration date" : "חייב תאריך תפוגה",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "הצגת טקסט הבהרה בעמוד ההעלאה בקישור הציבורי (מופיע רק כאשר רשימת הקבצים מוסתרת)",
     "This text will be shown on the public link upload page when the file list is hidden." : "טקסט זה יופיע בקישור עמוד ההעלאה של הקישור הציבורי כאשר רשימת הקבצים מוסתרת.",
@@ -136,9 +135,8 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "אימות דו־שלבי לא נאכף על החברים בקבוצות הבאות.",
     "Excluded groups" : "קבוצות חריגות",
     "Save changes" : "שמירת שינויים",
-    "Update to {update}" : "עדכון ל־{version}",
+    "Update to {update}" : "עדכון ל־{update}",
     "Remove" : "הסרה",
-    "Disable" : "ניטרול",
     "Featured" : "מומלץ",
     "This app is supported via your current Nextcloud subscription." : "יישומון זה נתמך על ידי מינוי ה־Nextcloud הנוכחי שלך.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "היישומונים המומלצים מפותחים על ידי ובתוך הקהילה. הם מציעים תכונות ליבה מסוימות והן מוכנות לשימוש יומיומי.",
@@ -152,6 +150,9 @@ OC.L10N.register(
     "Disable all" : "להשבית הכול",
     "_%n app has an update available_::_%n apps have an update available_" : ["לאחד היישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין"],
     "Loading" : "בטעינה",
+    "Daemon" : "סוכן",
+    "Type" : "סוג",
+    "Display Name" : "שם תצוגה",
     "Description" : "תיאור",
     "Details" : "פרטים",
     "All" : "הכל",
@@ -194,7 +195,6 @@ OC.L10N.register(
     "Could not copy app password. Please copy it manually." : "לא ניתן להעתיק את הססמה של היישומון. נא להעתיק אותה ידנית.",
     "Use system cron service to call the cron.php file every 5 minutes." : "להשתמש בשירות ה־cron של המערכת כדי לקרוא לקובץ cron.php כל 5 דקות.",
     "Profile" : "פרופיל",
-    "Enable" : "הפעלה",
     "Server-side encryption" : "הצפנת צד שרת",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "הצפנה בצד השרת מאפשרת להצפין קבצים שנשלחים לשרת. לתכונה זו יש מגבלות כגון ירידה בביצועים, מומלץ להפעיל רק אם יש צורך.",
     "Enable server-side encryption" : "הפעלת הצפנה בצד שרת",
@@ -286,7 +286,9 @@ OC.L10N.register(
     "Featured apps" : "יישומונים מובילים",
     "Hide" : "הסתרה",
     "Download and enable" : "להוריד ולהפעיל",
+    "Disable" : "ניטרול",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "היישומון הזה לא מסומן כנתמך בגרסת ה־Nextcloud. עדיין יתאפשר לך להמשיך ולהתקין את היישומון. נא לשים לב שיכול להיות שהיישומון לא יעבוד כצפוי.",
+    "Unknown" : "לא ידוע",
     "Never" : "מעולם לא",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "היישומון הופעל אך יש לעדכן אותו. ההפניה לעמוד העדכון תחל בעוד 5 שניות.",
     "Do you really want to wipe your data from this device?" : "להשמיד את הנתונים שלך במכשיר הזה?",
@@ -313,6 +315,7 @@ OC.L10N.register(
     "Credentials" : "פרטי גישה",
     "SMTP Password" : "סיסמת SMTP",
     "Save" : "שמור",
+    "Security & setup warnings" : "הזהרות אבטחה והתקנה",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "למטרות אבטחה וביצועים מיטביים עבור המערכת שלך חשוב שהכול יוגדר כראוי. כדי לסייע לך בכך אנו עורכים בדיקות אוטומטיות. נא לעיין בתיעוד המקושר לקבלת מידע נוסף.",
     "All checks passed." : "כל הבדיקות עברו",
     "There are some errors regarding your setup." : "ישנן מגוון שגיאות על ההגדרות שלך.",
@@ -323,7 +326,6 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "סיבות להשתמש ב־Nextcloud בארגון שלך",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "בפיתוח על ידי {communityopen}קהילת Nextcloud{linkclose}, {githubopen}קוד המקור{linkclose} זמין ברישיון {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "לייק לעמוד הפייסבוק שלנו",
-    "Follow us on Twitter" : "לעקוב אחרינו בטוויטר",
     "Follow us on Mastodon" : "למעקב אחרינו ב־Mastodon",
     "Check out our blog" : "לעיין בבלוג שלנו",
     "Subscribe to our newsletter" : "הרשמה לרשימת הדיוור שלנו",
@@ -339,6 +341,7 @@ OC.L10N.register(
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "למסד הנתונים חסרים אינדקסים. כיוון שהוספת אינדקסים על טבלאות גדולות היא פעולה שגוזלת זמן רב הם לא נוספים אוטומטית. על ידי הרצת הפקודה „occ db:add-missing-indices” האינדקסים החסרים נוספים ידנית ללא עצירת פעולת העותק. לאחר הוספת האינדקסים השאילתות על הטבלאות האלה מהירות בהרבה.",
     "Exclude groups from sharing" : "מניעת קבוצות משיתוף",
     "These groups will still be able to receive shares, but not to initiate them." : "קבוצות אלו עדיין יוכלו לקבל שיתופים, אך לא לשתף בעצמם.",
+    "Set default expiration date for shares" : "הגדרת תאריך תפוגה כבררת מחדל לשיתופים",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "ניתן לאכוף אימות דו־שלבי על כל המשתמשים ועל קבוצות מסוימות. אם אין להם ספק אימות דו־שלבי מוגדר, לא תהיה להם אפשרות להיכנס למערכת.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "כאשר קבוצות נבחרות/מוחרגות, הן משתמשות בלוגיקה הבאה כדי להחליט האם נאכף על המשתמש אימות דו־שלבי: אם לא נבחרו קבוצות, אימות דו־שלבי פעיל עבור כולם למעט החברים בקבוצות שהוחרגו. אם נבחרו קבוצות, אימות דו־שלבי מופעל לכל החברים של הקבוצות האלו. אם משתמש נמצא גם בקבוצה נבחרת וגם בקבוצה מוחרגת, הנבחרת מקבלת עדיפות ואימות דו־שלבי נאכף.",
     "{license}-licensed" : "ברישיון {license}",
@@ -359,6 +362,7 @@ OC.L10N.register(
     "by {author}\n{license}" : "מאת {author}\n{license}",
     "Active users" : "משתמשים פעילים",
     "Disabled users" : "משתמשים מושבתים",
-    "SMTP Username" : "שם משתמש SMTP "
+    "SMTP Username" : "שם משתמש SMTP ",
+    "Follow us on Twitter" : "לעקוב אחרינו בטוויטר"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
