@@ -50,17 +50,16 @@ OC.L10N.register(
     "Privacy policy" : "Polityka prywatności",
     "Adjust the Nextcloud theme" : "Dostosuj motyw Nextcloud",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motyw umożliwia na łatwą personalizację wyglądu instancji i wspieranych klientów. Ustawiony wygląd będzie widoczny dla wszystkich użytkowników.",
+    "Upload new logo" : "Wyślij nowe logo",
+    "Logo" : "Logo",
+    "Upload new background and login image" : "Wyślij nowe tło i obraz logowania",
+    "Background and login image" : "Obraz tła i logowania",
     "Advanced options" : "Opcje zaawansowane",
     "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Zainstaluj rozszerzenie ImageMagick PHP z obsługą obrazów SVG, aby automatycznie generować favikony na podstawie przesłanego logo i koloru.",
     "Name" : "Nazwa",
     "Web link" : "Link",
     "a safe home for all your data" : "bezpieczny dom dla wszystkich danych",
     "Slogan" : "Slogan",
-    "Color" : "Kolor",
-    "Logo" : "Logo",
-    "Upload new logo" : "Wyślij nowe logo",
-    "Background and login image" : "Obraz tła i logowania",
-    "Upload new background and login image" : "Wyślij nowe tło i obraz logowania",
     "Legal notice link" : "Link do informacji prawnej",
     "Privacy policy link" : "Link do polityki prywatności",
     "Header logo" : "Logo nagłówka",
@@ -70,6 +69,7 @@ OC.L10N.register(
     "User settings" : "Ustawienia użytkownika",
     "Disable user theming" : "Wyłącz motywy użytkownika",
     "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Chociaż możesz wybrać i dostosować swoją instancję, użytkownicy mogą zmieniać swoje tło i kolory. Jeśli chcesz wymusić dostosowanie, możesz to włączyć.",
+    "Enable blur background filter (may increase GPU load)" : "Włącz filtr rozmycia tła (może zwiększyć obciążenie GPU)",
     "Customization has been disabled by your administrator" : "Dostosowanie zostało wyłączone przez administratora",
     "Keyboard shortcuts" : "Skróty klawiaturowe",
     "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "W niektórych przypadkach skróty klawiaturowe mogą kolidować z narzędziami ułatwień dostępu. Aby umożliwić prawidłowe skupienie się na narzędziu, możesz tutaj wyłączyć wszystkie skróty klawiaturowe. Spowoduje to również wyłączenie wszystkich dostępnych skrótów w aplikacjach.",
@@ -80,9 +80,8 @@ OC.L10N.register(
     "Move up" : "Przenieś wyżej",
     "Move down" : "Przenieś niżej",
     "Custom background" : "Tło niestandardowe",
+    "Plain background" : "Zwykłe tło",
     "Default background" : "Tło domyślne",
-    "Change color" : "Zmień kolor",
-    "No background" : "Bez tła",
     "Select a background from your files" : "Wybierz tło ze swoich Plików",
     "Select background" : "Wybierz tło",
     "No background has been selected" : "Nie wybrano tła",
@@ -102,11 +101,14 @@ OC.L10N.register(
     "Default app priority" : "Domyślny priorytet aplikacji",
     "If an app is not enabled for a user, the next app with lower priority is used." : "Jeśli aplikacja nie jest włączona dla użytkownika, używana jest następna aplikacja o niższym priorytecie.",
     "Could not set global default apps" : "Nie można ustawić globalnych aplikacji domyślnych",
+    "Select a custom color" : "Wybierz kolor niestandardowy",
     "Reset to default" : "Przywróć domyślne",
     "Upload" : "Wyślij",
     "Remove background image" : "Usuń obraz tła",
+    "Color" : "Kolor",
     "Background" : "Tło",
     "Set a custom background" : "Ustaw niestandardowe tło",
-    "Select a custom color" : "Wybierz kolor niestandardowy"
+    "Change color" : "Zmień kolor",
+    "No background" : "Bez tła"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
