@@ -38,6 +38,7 @@ OC.L10N.register(
     "Reset your password" : "Restarigi vian pasvorton ",
     "Task not found" : "Tasko ne trovita",
     "Internal error" : "Interna eraro",
+    "Not found" : "Ne trovita",
     "Image not found" : "Bildo ne trovita",
     "Unable to translate" : "Ne eblas traduki",
     "Nextcloud Server" : "Nextcloud-servilo",
@@ -82,15 +83,30 @@ OC.L10N.register(
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La ĝisdatigo malsukcesis. Por pli da informoj, <a href=\"{url}\">vidu la forumafisôn</a> pri tio.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La ĝisdatigo malsukcesis. Bonvolu raporti tiun problemon al la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-komunumo</a>.",
     "Applications menu" : "Aplikaĵa menuo",
+    "Apps" : "Aplikaĵoj",
     "More apps" : "Pli da aplikaĵoj",
-    "Currently open" : "Aktuale malfermita",
     "_{count} notification_::_{count} notifications_" : ["{count} sciigoj","{count} sciigoj"],
     "No" : "Ne",
     "Yes" : "Jes",
+    "Failed to add the public link to your Nextcloud" : "Ne eblis aldoni la publikan ligilon al via Nextcloud",
     "Custom date range" : "Propra data periodo",
     "Pick start date" : "Elekti komencan daton",
     "Pick end date" : "Elekti finan daton",
     "Search in date range" : "Serĉi en data periodo",
+    "Date" : "Dato",
+    "Today" : "Hodiaŭ",
+    "Last 7 days" : "Lastaj 7 tagoj",
+    "Last 30 days" : "Lastaj 30 tagoj",
+    "This year" : "Ĉi jaro",
+    "Last year" : "Lasta jaro",
+    "Search people" : "Serĉi homojn",
+    "People" : "Homoj",
+    "Filter in current view" : "Filtrilo en ĉi vido",
+    "Search in" : "Serĉi en",
+    "Searching …" : "Serĉado ...",
+    "Start typing to search" : "Ektajpu por serĉi",
+    "No matching results" : "Neniuj kongruaj rezultoj",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Inter ${this.dateFilter.startFrom.toLocaleDateString()} kaj ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Ensaluti",
     "Logging in …" : "Ensaluti...",
     "Server side authentication failed!" : "Ĉeservila aŭtentigo malsukcesis!",
@@ -100,6 +116,7 @@ OC.L10N.register(
     "Password" : "Pasvorto",
     "Log in to {productName}" : "Saluti al {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
+    "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
     "Your account is not setup for passwordless login." : "Via konto ne estas agordita por uzi senpasvortan ensaluton.",
     "Passwordless authentication is not supported in your browser." : "Senpasvorta aŭtentigo ne eblas per via retumilo.",
     "Your connection is not secure" : "La konekto ne sekuras",
@@ -113,11 +130,13 @@ OC.L10N.register(
     "Resetting password" : "Restarigo de la pasvorto",
     "Recommended apps" : "Rekomendataj aplikaĵoj",
     "Loading apps …" : "Ŝargado de aplikaĵoj...",
-    "Installing apps …" : "Instalado de aplikaĵoj...",
     "App download or installation failed" : "Elŝuto aŭ instalado de la aplikaĵo malsukcesis",
     "Cannot install this app" : "La instalado de tiu aplikaĵo ne eblas",
     "Skip" : "Preterpasi",
+    "Installing apps …" : "Instalado de aplikaĵoj...",
     "Install recommended apps" : "Instali rekomendatajn aplikaĵojn",
+    "Settings menu" : "Menuo de agordo",
+    "Avatar of {displayName}" : "Avataro de {displayName}",
     "Reset search" : "Restarigi serĉon",
     "Search contacts …" : "Serĉi kontaktojn…",
     "Could not load your contacts" : "Ne eblis ŝargi viajn kontaktojn",
@@ -125,32 +144,15 @@ OC.L10N.register(
     "Install the Contacts app" : "Instali la Kontakto-aplikaĵon",
     "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
     "Looking for {term} …" : "Serĉo de {term}…",
-    "Start typing to search" : "Ektajpu por serĉi",
     "Search" : "Serĉi",
     "No results for {query}" : "Neniu rezulto pri {query}",
     "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
     "Back" : "Antaŭen",
-    "Edit Profile" : "Modifi profilon",
-    "Date" : "Dato",
-    "Today" : "Hodiaŭ",
-    "Last 7 days" : "Lastaj 7 tagoj",
-    "Last 30 days" : "Lastaj 30 tagoj",
-    "This year" : "Ĉi jaro",
-    "Last year" : "Lasta jaro",
-    "Search people" : "Serĉi homojn",
-    "Not found" : "Ne trovita",
-    "People" : "Homoj",
-    "Filter in current view" : "Filtrilo en ĉi vido",
-    "Search in" : "Serĉi en",
-    "Searching …" : "Serĉado ...",
-    "No matching results" : "Neniuj kongruaj rezultoj",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Inter ${this.dateFilter.startFrom.toLocaleDateString()} kaj ${this.dateFilter.endAt.toLocaleDateString()}",
+    "More actions" : "Pliaj agoj",
     "This browser is not supported" : "La retumilo ne estas subtenata",
     "Continue with this unsupported browser" : "Daŭrigi per tiu ne subtenata retumilo",
     "Supported versions" : "Subtenataj versioj",
     "{name} version {version} and above" : "{name} versio {version} kaj supre",
-    "Settings menu" : "Menuo de agordo",
-    "Avatar of {displayName}" : "Avataro de {displayName}",
     "Choose {file}" : "Elekti {file}",
     "Choose" : "Elekti",
     "Copy to {target}" : "Kopii al {target}",
@@ -202,19 +204,15 @@ OC.L10N.register(
     "No tags found" : "Neniu etikedo troviĝis ",
     "Personal" : "Persona",
     "Accounts" : "Kontoj",
-    "Apps" : "Aplikaĵoj",
     "Admin" : "Administranto",
     "Help" : "Helpo",
     "Access forbidden" : "Aliro estas malpermesata",
-    "Profile not found" : "Profilo ne troviĝis",
-    "The profile does not exist." : "La profilo ne ekzistas.",
-    "Back to %s" : "Antaŭen al %s",
     "Page not found" : "Paĝo ne trovita",
     "The page could not be found on the server or you may not be allowed to view it." : "La paĝo ne povis esti trovita en la servilo aŭ vi eble ne rajtas vidi ĝin.",
+    "Back to %s" : "Antaŭen al %s",
     "Too many requests" : "Tro da petoj",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Estis tro multaj petoj de via reto. Reprovu poste aŭ kontaktu vian administranton se tio estas eraro.",
     "Error" : "Eraro",
-    "Previous" : "Antaŭa",
     "Internal Server Error" : "Interna servileraro",
     "The server was unable to complete your request." : "La servilo ne eblis plenumi vian peton.",
     "If this happens again, please send the technical details below to the server administrator." : "Se tio denove okazos, bv. sendi la teĥnikajn detalojn ĉi-sube al la administranto de la servilo.",
@@ -231,7 +229,6 @@ OC.L10N.register(
     "Security warning" : "Sekureca averto",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
-    "Create an <strong>admin account</strong>" : "Krei <strong>administranto-konton</strong>",
     "Show password" : "Montri pasvorton",
     "Toggle password visibility" : "Ŝanĝi videblecon de pasvorto",
     "Storage & database" : "Konservejo kaj datumbazo",
@@ -272,6 +269,7 @@ OC.L10N.register(
     "Account connected" : "Konto konektita",
     "Your client should now be connected!" : "Via kliento estas konektita!",
     "You can close this window." : "Vi povas fermi tiun ĉi fenestron.",
+    "Previous" : "Antaŭa",
     "This share is password-protected" : "Tiu kunhavigo estas protektata per pasvorto",
     "The password is wrong or expired. Please try again or request a new one." : "La pasvorto estas malĝusta aŭ eksvalidiĝis. Bonvolu provi denove aŭ peti novan.",
     "Email address" : "Retpoŝtadreso",
@@ -312,66 +310,23 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Via retservilo ne estas bone agordita por trovi la adreson „{url}“. Pli da informo troveblas en la {linkstart}dokumentaro ↗{linkend}.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Via retservilo ne estas bone agordita por trovi la adreson „{url}“. Tio plej verŝajne estas kaŭzita de servilo ne ĝisdatigita por rekte liveri tiun ĉi dosierujon. Bv. kompari vian agordon al transformreguloj en „.htaccess“ por Apache, aŭ la reguloj por Nginx en la {linkstart}dokumentaro ↗{linkend}. Ĉe Nginx, tio, kio devas ĝisdatiĝi estas kutime linioj komencantaj per „location ~“.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Via retservilo ne estas bone agordita por sendi .woff2-dosierojn. Tio estas tipe problemo kun la agordo de Nginx. Nextcloud 15 bezonas adapton por ankaŭ sendi .woff2-dosierojn. Komparu vian Nginx-agordon kun la rekomendita agordo en nia {linkstart}dokumentaro ↗{linkend}.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ŝajnas ne esti taŭge agordita por informpeti sistemajn medivariablojn. La testado kun getenv(\"PATH\") revenigas nur malplenan respondon.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Bv. legi la {linkstart}instal-dokumentaron ↗{linkend} pri agordo-notoj pri PHP kaj pri PHP-agordo de via retservilo, precipe kiam vi uzas la modulon „php-fpm“.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La nurlega agordodosiero estis ebligita. Tio baras modifon de kelkaj agordoj per la reta fasado. Plie, la dosiero bezonos esti markita mane kiel legebla dum ĉiu ĝisdatigo.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Via datumbazo ne uzas la nivelon de izoltransakcio „READ COMMITTED“ (angle por „asertita datumlegado“). Tio povas estigi problemojn, kiam pluraj agoj ruliĝas paralele.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "La PHP-modulo „fileinfo“ mankas. Oni rekomendas ebligi tiun modulon por havi la plej bonan malkovron de MIME-tipo.",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Via instalaĵo ne difinas defaŭltan telefon-regionon. Tio necesas por validigi telefonnumerojn en la profil-agordoj sen landkodo. Por ebligi la uzon de numeroj sen lankodo, aldonu „default_phone_region“ kun la {linkstart}ISO-3166-1-kodo ↗{linkend} de via regiono en la agordodosiero.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ne eblis ruli la cron-taskon per komandlinia interfaco. La jenaj eraroj okazis:",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La PHP-funkcio „set_time_limit“ (angle „difini tempolimo“) ne disponeblas. Pro tio, skriptoj povus halti mezvoje, eble difektante vian instalaĵon. Ebligi tiun funkcion estas tre rekomendita.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Via PHP ne subtenas la bibliotekon FreeType, kio provokos misfunkcion de profilbildo kaj de la agorda fasado.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Mankanta indekso „{indexName}“ en tabelo „{tableName}“.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankas kelkaj indeksoj en la datumbazo. Pro la ebla malrapideco aldoni indeksojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-indices“, dum la servilo estas funkcianta. Kiam la indeksoj ekzistos, la uzo de tiuj tabelojn estos kutime pli rapida.",
-    "Missing primary key on table \"{tableName}\"." : "Mankas ĉefŝlosilo ĉe la tablo „{tableName}“.",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Mankas kelkaj ĉefŝlosiloj en la datumbazo. Pro la ebla malrapideco aldoni ĉefŝlosilojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-primary-keys“, dum la servilo estas funkcianta.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Mankas malnepra kolumno ĉe la tablo „{tableName}“.",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankas kelkaj malnepraj kolumnoj en la datumbazo. Pro la ebla malrapideco aldoni kolumnojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-columns“, dum la servilo estas funkcianta. Kiam la kolumnoj aldoniĝos, la uzo de tiuj tabelojn estos kutime pli rapida.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "En tiu servilo mankas rekomenditaj PHP-moduloj. Por pli da rapideco kaj pli bona kongrueco, bv. instali ilin.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "En tiu servilo, la PHP-modulo „php-imagick“ ne subtenas SVG. Por pli bona kongrueco, instalu ĝin.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite estas la nuna datumbazo uzita de la servilo. Por grandaj instalaĵoj, ni rekomendas uzi alian tipon de datumbazo.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Tio estas precipe rekomendinda, kiam oni uzas la surtablan programon por sinkronigi la dosierojn.",
-    "The PHP memory limit is below the recommended value of 512MB." : "La PHP-memorlimo estas sub la rekomendita valoro de 512 MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Kelkaj aplikaĵ-dosierujoj apartenas al malsama uzanto ol tiu de la retservilo. Tio povas okazi, kiam aplikaĵoj estis instalita mane. Kontrolu la permesojn de la jenaj dosierujoj:",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Tiu Nextcloud-servilo uzas objektokonservejon bazitan sur S3 kiel ĉefkonservejo. La alŝutitaj dosieroj provizore konserviĝas en la servilo, kaj pro tio oni rekomendas havi liberan spacon je 50 GB en la PHP-a provizora dosierujo. Kontrolu la protokolojn por ĉiuj detaloj pri la dosiervojo kaj la libera spaco. Do, aŭ ŝanĝu la provizoran dosierujon en „php.ini“, aŭ liberigu spacon en tiu loko.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La HTTP-kapo „{header}“ ne egalas al „{expected}“. Tio estas eventuala risko pri sekureco aŭ privateco. Bv. ĝustigi tiun agordon laŭe.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "La HTTP-kapo „{header}“ ne egalas al „{expected}“. Iuj trajtoj povus ne funkcii ĝuste. Bv. ĝustigi tiun agordon laŭe.",
-    "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
+    "Currently open" : "Aktuale malfermita",
     "Wrong username or password." : "Neĝusta uzantnomo aŭ pasvorto.",
     "User disabled" : "Uzanto malvalidigita",
     "Username or email" : "Uzantnomo aŭ retpoŝtadreso",
-    "Start search" : "Ekserĉi",
-    "Open settings menu" : "Malfermi agardan menuon",
-    "Settings" : "Agordo",
-    "Avatar of {fullName}" : "Avataro de {fullName}",
-    "Show all contacts …" : "Montri ĉiujn kontaktojn",
-    "No files in here" : "Neniu dosiero ĉi tie",
-    "New folder" : "Nova dosierujo",
-    "No more subfolders in here" : "Ne plu estas subdosierujo ĉi tie.",
-    "Name" : "Nomo",
-    "Size" : "Grando",
-    "Modified" : "Modifita",
-    "\"{name}\" is an invalid file name." : "„{name}“ estas nevalida dosiernomo.",
-    "File name cannot be empty." : "Dosiernomo devas ne malpleni.",
-    "\"/\" is not allowed inside a file name." : "Ne eblas uziĝi „/“ en dosiernomo.",
-    "\"{name}\" is not an allowed filetype" : "„{name}“ estas nepermesita dosiertipo",
-    "{newName} already exists" : "{newName} jam ekzistas",
-    "Error loading file picker template: {error}" : "Eraro dum ŝargo de ŝablono pri dosier-elektilo: {error}",
-    "Error loading message template: {error}" : "Eraro dum ŝargo de mesaĝa ŝablono: {eraro}",
-    "Show list view" : "Montri listan vidon",
-    "Show grid view" : "Montri kradan vidon",
-    "Pending" : "Pritraktota",
-    "Home" : "Hejmo",
-    "Copy to {folder}" : "Kopii al {folder}",
-    "Move to {folder}" : "Movi al {folder}",
-    "Authentication required" : "Aŭtentiĝo nepras",
-    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas, ke vi konfirmas vian pasvorton",
-    "Confirm" : "Konfirmi",
-    "Failed to authenticate, try again" : "Malsukcesis aŭtentigi, provu ree",
+    "Edit Profile" : "Modifi profilon",
+    "Error loading message template: {error}" : "Eraro dum ŝargo de mesaĝa ŝablono: {error}",
     "Users" : "Uzantoj",
+    "Profile not found" : "Profilo ne troviĝis",
+    "The profile does not exist." : "La profilo ne ekzistas.",
+    "Create an <strong>admin account</strong>" : "Krei <strong>administranto-konton</strong>",
     "Username" : "Uzantnomo",
     "Database user" : "Datumbaza uzanto",
+    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas, ke vi konfirmas vian pasvorton",
     "Confirm your password" : "Konfirmu vian pasvorton",
+    "Confirm" : "Konfirmi",
     "App token" : "Aplikaĵa ĵetono",
     "Alternative log in using app token" : "Ensaluti alimaniere per aplikaĵa ĵetono",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Bv. uzi la komandlinian ĝisdatigilon, ĉar vi havas pli da 50 uzantojn en tiu servilo."
