@@ -136,14 +136,7 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El rerefons d'ús compartit %s ha d'implementar la interfície OCP\\Share_Backend",
     "Sharing backend %s not found" : "No s'ha trobat el rerefons d'ús compartit %s",
     "Sharing backend for %s not found" : "No s'ha trobat el rerefons d'ús compartit per a %s",
-    "%1$s shared »%2$s« with you" : "%1$s ha compartit «%2$s» amb vós",
-    "%1$s shared »%2$s« with you." : "%1$s ha compartit «%2$s» amb vós.",
-    "Click the button below to open it." : "Feu clic en el botó següent per a obrir-ho.",
-    "Open »%s«" : "Obre «%s»",
     "%1$s via %2$s" : "%1$s mitjançant %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha compartit «%2$s» amb vós i vol afegir:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha compartit «%2$s» amb vós i vol afegir",
-    "»%s« added a note to a file shared with you" : "%s ha afegit una nota a un fitxer compartit amb vós",
     "Unknown share type" : "Tipus d'element compartit desconegut",
     "You are not allowed to share %s" : "No podeu compartir %s",
     "Cannot increase permissions of %s" : "No es poden augmentar els permisos de %s",
@@ -214,8 +207,6 @@ OC.L10N.register(
     "Login canceled by app" : "L'aplicació ha cancel·lat l'inici de sessió",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'aplicació «%1$s» no es pot instal·lar perquè no es compleixen les dependències següents: %2$s",
     "a safe home for all your data" : "Un lloc segur per a totes les vostres dades",
-    "File is currently busy, please try again later" : "El fitxer està ocupat actualment; torneu-ho a provar més tard",
-    "Cannot download file" : "No es pot baixar el fitxer",
     "Application is not enabled" : "L'aplicació no està habilitada",
     "Authentication error" : "Error d'autenticació",
     "Token expired. Please reload page." : "El testimoni ha caducat. Torneu a carregar la pàgina.",
@@ -259,7 +250,9 @@ OC.L10N.register(
     "Storage connection error. %s" : "S'ha produït un error de connexió amb l'emmagatzematge. %s",
     "Storage is temporarily not available" : "L'emmagatzematge no està disponible temporalment",
     "Storage connection timeout. %s" : "S'ha superat el temps d'espera de la connexió d'emmagatzematge. %s",
+    "Confirmation" : "Confirmació",
     "Generates a possible headline for a text." : "Genera un titular possible per a un text.",
+    "Text" : "Text",
     "Summarize" : "Resumeix",
     "Summary" : "Resum",
     "Extract topics" : "Extreu els temes",
@@ -287,7 +280,14 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "El nom d'usuari o la contrasenya d'Oracle no són vàlids",
     "PostgreSQL username and/or password not valid" : "El nom d'usuari o la contrasenya del PostgreSQL no són vàlids",
     "Set an admin username." : "Definiu un nom d'usuari per a l'administrador.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha compartit «%2$s» amb vós i vol afegir:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha compartit «%2$s» amb vós i vol afegir",
+    "»%s« added a note to a file shared with you" : "%s ha afegit una nota a un fitxer compartit amb vós",
+    "Open »%s«" : "Obre «%s»",
     "Sharing %s failed, because this item is already shared with user %s" : "No s'ha pogut compartir %s perquè l'element ja està compartit amb l'usuari %s",
+    "%1$s shared »%2$s« with you" : "%1$s ha compartit «%2$s» amb vós",
+    "%1$s shared »%2$s« with you." : "%1$s ha compartit «%2$s» amb vós.",
+    "Click the button below to open it." : "Feu clic en el botó següent per a obrir-ho.",
     "The username is already being used" : "El nom d'usuari ja està en ús",
     "Could not create user" : "No s'ha pogut crear l'usuari",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Només es permeten els caràcters següents en un nom d'usuari: «a-z», «A-Z», «0-9», espais i «_.@-'»",
@@ -296,6 +296,8 @@ OC.L10N.register(
     "Username must not consist of dots only" : "El nom d'usuari no pot estar format només per punts",
     "Username is invalid because files already exist for this user" : "El nom d'usuari no és vàlid perquè ja existeixen fitxers per a aquest usuari",
     "User disabled" : "Usuari inhabilitat",
+    "File is currently busy, please try again later" : "El fitxer està ocupat actualment; torneu-ho a provar més tard",
+    "Cannot download file" : "No es pot baixar el fitxer",
     "Your data directory is readable by other users." : "Els altres usuaris poden llegir la carpeta de dades.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Canvieu els permisos a 0770 perquè els altres usuaris no puguin veure el contingut de la carpeta.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegureu-vos que hi hagi un fitxer anomenat «.ocdata» en l'arrel de la carpeta de dades."
