@@ -87,12 +87,22 @@ OC.L10N.register(
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" ez da onartzen fitxategi edo karpeta-izen baten barruan.",
     "\"%1$s\" is a forbidden file type." : "\"%1$s\" debekatutako fitxategi mota bat da.",
     "Filenames must not end with \"%1$s\"." : "Fitxategi-izenak ez dira \"%1$s\"rekin amaitu behar.",
+    "Invalid parent path" : "Guraso bide-izen baliogabea",
     "File already exists" : "Badago izen bereko fitxategi bat",
     "Invalid path" : "Bide-izen baliogabea",
     "Failed to create file from template" : "Fitxategi berria txantiloitik sortzeak huts egin du",
     "Templates" : "Txantiloiak",
+    "Storage %s cannot be moved" : "%s biltegia ezin da mugitu",
+    "Moving a share (%s) into a shared folder is not allowed" : "Partekatze bat (%s) partekatutako karpeta batera mugitzea ez dago baimenduta",
+    "Moving a storage (%s) into a shared folder is not allowed" : "Biltegi bat (%s) partekatutako karpeta batera mugitzea ez dago baimenduta",
+    "Moving a share (%s) into another share (%s) is not allowed" : "Partekatze bat (%s) beste partekatze (%s) batera mugitzea ez dago baimenduta",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "Biltegi bat (%s) beste biltegi (%s) batera mugitzea ez dago baimenduta",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Biltegi bat (%s) partekatze (%s) batera mugitzea ez dago baimenduta",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "Biltegi bat (%s) beste biltegi (%s) batera mugitzea ez dago baimenduta",
     "Path contains invalid segments" : "Bideak segmentu baliogabeak ditu",
+    "Filename is a reserved word" : "Fitxategi izena hitz erreserbatua da",
     "Filename contains at least one invalid character" : "Fitxategi-izenak karaktere baliogabe bat du gutxienez",
+    "Filename is too long" : "Fitxategi-izena luzeegia da",
     "Empty filename is not allowed" : "Fitxategiaren izena ezin da hutsa izan",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "«%s» aplikazioa ezin da instalatu appinfo fitxategia ezin delako irakurri.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" aplikazioa ezin da instalatu ez delako zerbitzariaren bertsio honekin bateragarria.",
@@ -123,6 +133,7 @@ OC.L10N.register(
     "Headline" : "Izenburua",
     "Organisation" : "Erakundea",
     "Role" : "Zeregina",
+    "Pronouns" : "Izenordainak",
     "Unknown account" : "Kontu ezezaguna",
     "Additional settings" : "Ezarpen gehiago",
     "Enter the database Login and name for %s" : "Sartu datu-basearen saioa eta izena %s(r)entzako",
@@ -144,24 +155,54 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s partekatze motorrak OCP\\Share_Backend interfazea inplementatu behar du ",
     "Sharing backend %s not found" : "Ez da %s partekatze motorra aurkitu",
     "Sharing backend for %s not found" : "Ez da %s(e)rako partekatze motorrik aurkitu",
-    "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
-    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
-    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
-    "Open »%s«" : "Ireki »%s«",
+    "%1$s shared %2$s with you" : "%1$sk %2$s partekatu du zurekin",
+    "Open %s" : "Ireki %s",
     "%1$s via %2$s" : "%2$s bidez, %1$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du",
-    "»%s« added a note to a file shared with you" : "»%s« erabiltzaileak ohar bat gehitu du partekatu dizun fitxategi batean",
+    "%1$s shared %2$s with you and wants to add:" : "%1$serabiltzaileak %2$s partekatu du zurekin eta hau gehitu nahi du:",
+    "%1$s shared %2$s with you and wants to add" : "%1$serabiltzaileak %2$s partekatu du zurekin eta hau gehitu nahi du",
+    "%s added a note to a file shared with you" : "%s erabiltzaileak ohar bat gehitu du partekatu dizun fitxategi batean",
+    "Passwords are enforced for link and mail shares" : "Esteka eta posta partekatzeentzako pasahitzak behartzen dira",
+    "Share recipient is not a valid user" : "Partekatzearen hartzailea ez da baliozko erabiltzailea",
+    "Share recipient is not a valid group" : "Partekatzearen hartzailea ez da baliozko taldea",
+    "Share recipient should be empty" : "Partekatzearen hartzailea huts egon beharko luke",
+    "Share recipient should not be empty" : "Partekatzearen hartzailea ez luke huts egon beharko",
+    "Share recipient is not a valid circle" : "Partekatzearen hartzailea ez da baliozko zirkulua",
     "Unknown share type" : "Partekatze mota ezezaguna",
+    "Share initiator must be set" : "Partekatzearen hasieratzailea ezarri behar da",
+    "Cannot share with yourself" : "Ezin duzu zurekin partekatu",
+    "Shared path must be set" : "Partekatzearen bide-izena ezarri behar da",
+    "Shared path must be either a file or a folder" : "Partekatzearen bide-izena fitxategi edo karpeta bat izan behar da",
+    "You cannot share your root folder" : "Ezin duzu zure erro-karpeta partekatu",
     "You are not allowed to share %s" : "Ez duzu %s partekatzeko baimenik",
+    "Valid permissions are required for sharing" : "Baliozko baimenak behar dira partekatzeko",
     "Cannot increase permissions of %s" : "Ezin dira %s(r)en baimenak handitu",
+    "Shares need at least read permissions" : "Partekatzeak gutxienez irakurtzeko baimenak izan behar ditu",
     "Files cannot be shared with delete permissions" : "Fitxategiak ezin dira ezabatze baimenarekin partekatu",
     "Files cannot be shared with create permissions" : "Fitxategiak ezin dira sortze baimenarekin partekatu",
     "Expiration date is in the past" : "Iraungitze-data iraganean dago",
+    "Expiration date is enforced" : "Iraungitze-data betearazten da",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri","Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri"],
     "Sharing is only allowed with group members" : "Taldeko kideekin bakarrik parteka daiteke",
     "Sharing %s failed, because this item is already shared with the account %s" : "%s partekatzeak huts egin du, dagoeneko %s kontuarekin partekatuta dagoelako",
+    "Group sharing is now allowed" : "Talde-partekatzea baimentzen da orain",
+    "Sharing is only allowed within your own groups" : "Soilik zure taldeekin partekatu dezakezu",
+    "Path is already shared with this group" : "Bide-izen hau dagoeneko partekatuta dago talde honekin",
+    "Link sharing is not allowed" : "Esteken partekatzea ez da onartzen",
+    "Public upload is not allowed" : "Igotze publikoa ez da onartzen",
+    "Path contains files shared with you" : "Bide-izenak zurekin partekatutako fitxategiak dauzka",
     "Sharing is disabled" : "Partekatzea desgaituta dago",
+    "Sharing is disabled for you" : "Partekatzea zuretzat desgaituta dago",
+    "Cannot share with the share owner" : "Ezin da partekatzearen jabearekin partekatu",
+    "Share does not have a full ID" : "Partekatzeak ez dauka ID oso bat",
+    "Cannot change share type" : "Ezin da partekatze mota aldatu",
+    "Can only update recipient on user shares" : "Hartzailea erabiltzaile-partekatzeetan soilik eguneratu daiteke",
+    "Cannot enable sending the password by Talk with an empty password" : "Ezin da gaitu Talk-en bidez pasahitza bidaltzea pasahitza hutsik badago",
+    "Cannot enable sending the password by Talk without setting a new password" : "Ezin da gaitu Talk-en bidez pasahitza bidaltzea pasahitz berria ezarri gabe",
+    "Cannot disable sending the password by Talk without setting a new password" : "Ezin da desgaitu Talk-en bidez pasahitza bidaltzea pasahitz berria ezarri gabe",
+    "Share provider does not support accepting" : "Partekatzearen hornitzaileak ez du onarpena onartzen",
+    "Cannot change target of link share" : "Ezin da esteka partekatze baten helburua aldatu",
+    "Invalid share recipient" : "Partekatze-hartzaile baliogabea",
+    "Group \"%s\" does not exist" : "«%s» ez da existitzen",
     "The requested share does not exist anymore" : "Eskatutako partekatzea ez da existitzen dagoeneko",
     "The requested share comes from a disabled user" : "Eskatutako partekatzea desgaitutako erabiltzaile batengatik dator",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Ezin izan da erabiltzailea sortu, erabiltzaile muga gainditu delako. Egiaztatu zure jakinarazpenak gehiago jakiteko.",
@@ -225,8 +266,6 @@ OC.L10N.register(
     "Login canceled by app" : "Aplikazioak saioa bertan behera utzi du",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" aplikazioa ezin da instalatu, menpekotasun hauek betetzen ez direlako:%2$s",
     "a safe home for all your data" : "zure datu guztientzako toki segurua",
-    "File is currently busy, please try again later" : "Fitxategia lanpetuta dago, saiatu berriro geroago",
-    "Cannot download file" : "Ezin da fitxategia deskargatu",
     "Application is not enabled" : "Aplikazioa ez dago gaituta",
     "Authentication error" : "Autentifikazio errorea",
     "Token expired. Please reload page." : "Tokena iraungitu da. Mesedez birkargatu orria.",
@@ -271,12 +310,27 @@ OC.L10N.register(
     "Storage connection error. %s" : "Biltegiratze-konexioaren errorea. %s",
     "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
     "Storage connection timeout. %s" : "Biltegiratze-konexioa denboraz kanpo geratu da. %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Egiaztapen hau exekuta dadin ziurtatu behar duzu zure web zerbitzaria bere buruarekin konektatu daitekeela. Hori dela eta, bere `trusted_domains` edo `overwrite.cli.url`ra gutxienez ebatzi eta konektatzeko gai izan behar du. Baliteke hutsegite hau zerbitzariaren aldeko DNS ez bat etortzea edo irteerako suebakiaren arauaren ondorioa izatea.",
     "Transcribe audio" : "Audioa transkribatu",
     "Transcribe the things said in an audio" : "Audio batean esandako gauzak transkribatu",
     "Audio input" : "Audio sarrera",
     "The audio to transcribe" : "Transkribatzeko audioa",
     "Transcription" : "Transkripzioa",
     "The transcribed text" : "Transkribatutako testua",
+    "ContextAgent" : "ContextAgent",
+    "Chat with an agent" : "Txateatu agente batekin",
+    "Chat message" : "Txat mezua",
+    "A chat message to send to the agent." : "Agenteari bidaltzeko txat mezu bat.",
+    "Confirmation" : "Berrespena",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Aurretik eskatutako ekintzak berretsi behar diren ala ez: 0 ukatzeko eta 1 berresteko.",
+    "Conversation token" : "Elkarrizketa tokena",
+    "A token representing the conversation." : "Elkarrizketa adierazten duen token bat.",
+    "Generated response" : "Sortutako erantzuna",
+    "The response from the chat model." : "Txat modeloaren erantzuna.",
+    "The new conversation token" : "Elkarrizketa token berria",
+    "Send this along with the next interaction." : "Bidali hau hurrengo interakzioarekin.",
+    "Requested actions by the agent" : "Agenteak eskatutako ekintzak",
+    "Actions that the agent would like to carry out in JSON format." : "Agenteak egin nahi dituen ekintzak JSON formatuan.",
     "Context write" : "Testuingurua idaztea",
     "Writes text in a given style based on the provided source material." : "Testua estilo jakin batean idazten du, emandako iturri-materialean oinarrituta.",
     "Writing style" : "Idazteko estiloa",
@@ -303,15 +357,29 @@ OC.L10N.register(
     "Describe a task that you want the assistant to do or ask a question" : "Deskribatu laguntzaileak egitea nahi duzun zeregina edo galdera bat egin",
     "Generated reply" : "Sortutako erantzuna",
     "The generated text from the assistant" : "Laguntzaileak sortutako testua",
+    "Change Tone" : "Aldatu tonoa",
+    "Change the tone of a piece of text." : "Aldatu testu-zati baten tonua.",
+    "Write a text that you want the assistant to rewrite in another tone." : "Idatzi laguntzaileak beste tonu batean berridaztea nahi duzun testua.",
+    "Desired tone" : "Nahi den tonua",
+    "In which tone should your text be rewritten?" : "Ze tonuan berridatzi beharko litzateke zure testua?",
+    "The rewritten text in the desired tone, written by the assistant:" : "Berridatzitako testua nahi den tonuan, laguntzaileak idatzita:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Hitz egin txat bidez laguntzailarekin",
     "System prompt" : "Sistemaren gonbita",
     "Define rules and assumptions that the assistant should follow during the conversation." : "Definitu elkarrizketan zehar txat laguntzaileak jarraitu beharko lituzkeen arau eta suposizioak.",
-    "Chat message" : "Txat mezua",
     "Chat history" : "Txat historia",
     "The history of chat messages before the current message, starting with a message by the user" : "Uneko mezuaren aurreko txat mezuen historia, erabiltzailearen mezu batetik hasita",
     "Response message" : "Erantzun mezua",
     "The generated response as part of the conversation" : "Sorturiko erantzuna, elkarrizketaren zati gisa",
+    "Chat with tools" : "Txateatu erremintekin",
+    "Chat with the language model with tool calling support." : "Txateatu hizkuntza-modeloarekin dei-tresna euskarriarekin.",
+    "Tool message" : "Erreminta-mezua",
+    "The result of tool calls in the last interaction" : "Tresna-deien emaitza azken interakzioan",
+    "Available tools" : "Erreminta erabilgarriak",
+    "The available tools in JSON format" : "Erabilgarri dauden erremintak JSON formatuan",
+    "The response from the chat model" : "Txat modeloaren erantzuna",
+    "Tool calls" : "Erreminta deiak",
+    "Tools call instructions from the model in JSON format" : "Tresna-deien argibideak modelotik JSON formatuan",
     "Formalize text" : "Formaldu testua",
     "Takes a text and makes it sound more formal" : "Testu bat hartzen du eta doinu formalagoa ematen dio.",
     "Write a text that you want the assistant to formalize" : "Idatz ezazu laguntzaileak formaltzea nahi duzun testu bat",
@@ -322,6 +390,12 @@ OC.L10N.register(
     "Original text" : "Jatorrizko testua",
     "The original text to generate a headline for" : "Izenburu bat sortzeko jatorrizko testua",
     "The generated headline" : "Sortutako izenburua",
+    "Proofread" : "Testu-azterketa",
+    "Proofreads a text and lists corrections" : "Testu bat aztertzen du eta zuzenketak zerrendatzen ditu",
+    "Text" : "Testua",
+    "The text to proofread" : "Aztertzeko testua",
+    "Corrections" : "Zuzenketak",
+    "The corrections that should be made in your text" : "Zure testuan egin behar diren zuzenketak",
     "Reformulate text" : "Birformulatu testua",
     "Takes a text and reformulates it" : "Testu bat hartu eta birformulatu egiten du",
     "Write a text that you want the assistant to reformulate" : "Idatz ezazu laguntzaileak birformulatzea nahi duzun testu bat",
@@ -373,7 +447,14 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "Oracle erabiltzaile edo/eta pasahitza ez dira baliozkoak.",
     "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzailea edo/eta pasahitza ez dira baliozkoak.",
     "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du",
+    "»%s« added a note to a file shared with you" : "»%s« erabiltzaileak ohar bat gehitu du partekatu dizun fitxategi batean",
+    "Open »%s«" : "Ireki »%s«",
     "Sharing %s failed, because this item is already shared with user %s" : "%s partekatzeak huts egin du dagoeneko %serabiltzailearekin partekatuta dagoelako",
+    "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
+    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
+    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
     "The username is already being used" : "Erabiltzaile izena dagoeneko erabilita dago",
     "Could not create user" : "Ezin izan da erabiltzailea sortu",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Honako karaktereak bakarrik onartzen dira erabiltzaile izenetan: \"a-z\", \"A-Z\", \"0-9\", zuriuneak eta \"_.@-'\"",
@@ -382,6 +463,8 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Erabiltzaile-izena ezin da puntuz osatuta soilik egon",
     "Username is invalid because files already exist for this user" : "Erabiltzaile-izena ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
     "User disabled" : "Erabiltzaile desgaituta",
+    "File is currently busy, please try again later" : "Fitxategia lanpetuta dago, saiatu berriro geroago",
+    "Cannot download file" : "Ezin da fitxategia deskargatu",
     "Your data directory is readable by other users." : "Zure datuen karpeta beste erabiltzaileek irakur dezakete.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ziurtatu datu direktorioaren erroan \".ocdata\" izeneko fitxategia dagoela."
