@@ -126,6 +126,7 @@ OC.L10N.register(
     "Headline" : "Titular",
     "Organisation" : "Organización",
     "Role" : "Cargo",
+    "Pronouns" : "Pronomes",
     "Unknown account" : "Conta descoñecida",
     "Additional settings" : "Axustes adicionais",
     "Enter the database Login and name for %s" : "Introduza o acceso a base de datos e o nome para %s",
@@ -147,28 +148,26 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Non se atopou a infraestrutura de compartición %s",
     "Sharing backend for %s not found" : "Non se atopou a infraestrutura de compartición para %s",
-    "%1$s shared »%2$s« with you" : "%1$s compartiu «%2$s» con Vde.",
-    "%1$s shared »%2$s« with you." : "%1$s compartiu «%2$s» con Vde.",
-    "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
-    "Open »%s«" : "Abrir «%s»",
+    "%1$s shared %2$s with you" : "%1$s compartiu %2$s con Vde.",
+    "Open %s" : "Abrir %s",
     "%1$s via %2$s" : "%1$s mediante %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartiu «%2$s» con Vde. e quere engadir:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartiu «%2$s» con Vde. e quere engadir",
-    "»%s« added a note to a file shared with you" : "«%s» engadiu unha nota a un ficheiro compartido con Vde.",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s compartiu %2$s con Vde. e quere engadir:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s compartiu %2$s con Vde. e quere engadir",
+    "%s added a note to a file shared with you" : "%s engadiu unha nota a un ficheiro compartido con Vde.",
     "Passwords are enforced for link and mail shares" : "É obrigatorio o emprego de contrasinais para compartir por ligazón e por correo",
-    "SharedWith is not a valid user" : "O destinatario da compartición non é un usuario válido",
-    "SharedWith is not a valid group" : "O destinatario da compartición non é un grupo válido",
-    "SharedWith should be empty" : "O destinatario da compartición debe estar baleiro",
-    "SharedWith should not be empty" : "O destinatario da compartición non debe estar baleiro",
-    "SharedWith is not a valid circle" : "O destinatario da compartición non é un círculo válido",
+    "Share recipient is not a valid user" : "O destinatario da compartición non é un usuario válido",
+    "Share recipient is not a valid group" : "O destinatario da compartición non é un grupo válido",
+    "Share recipient should be empty" : "O destinatario da compartición debe estar baleiro",
+    "Share recipient should not be empty" : "O destinatario da compartición non debe estar baleiro",
+    "Share recipient is not a valid circle" : "O destinatario da compartición non é un círculo válido",
     "Unknown share type" : "Tipo descoñecido de compartición",
-    "SharedBy should be set" : "Debe estar definido quen inicia a compartición",
+    "Share initiator must be set" : "Debe estar definido quen inicia a compartición",
     "Cannot share with yourself" : "Non é posíbel compartir con un mesmo.",
-    "Path should be set" : "A ruta compartida debe estar definida",
-    "Path should be either a file or a folder" : "A ruta compartida debe ser a un ficheiro ou un cartafol",
+    "Shared path must be set" : "Debe estar definida a ruta compartida",
+    "Shared path must be either a file or a folder" : "A ruta compartida debe ser a un ficheiro ou un cartafol",
     "You cannot share your root folder" : "Non pode compartir o seu cartafol raíz",
     "You are not allowed to share %s" : "Non ten permiso para compartir %s",
-    "A share requires permissions" : "Requírense permisos válidos para compartir",
+    "Valid permissions are required for sharing" : "Precisanse permisos válidos para compartir",
     "Cannot increase permissions of %s" : "Non é posíbel incrementar os permisos de %s",
     "Shares need at least read permissions" : "As comparticións necesitan polo menos permisos de lectura",
     "Files cannot be shared with delete permissions" : "Non é posíbel compartir ficheiros con permisos de eliminación",
@@ -195,7 +194,7 @@ OC.L10N.register(
     "Cannot disable sending the password by Talk without setting a new password" : "Non é posíbel desactivar o envío do contrasinal por Talk sen definir un novo contrasinal",
     "Share provider does not support accepting" : "O provedor de comparticións non admite a aceptación",
     "Cannot change target of link share" : "Non é posíbel cambiar o destino da ligazón compartida",
-    "Invalid recipient" : "Destinatario de compartición incorrecto",
+    "Invalid share recipient" : "Destinatario de compartición incorrecto",
     "Group \"%s\" does not exist" : "O grupo «%s» non existe",
     "The requested share does not exist anymore" : "A compartición solicitada xa non existe",
     "The requested share comes from a disabled user" : "A compartición solicitada procede dun usuario desactivado",
@@ -260,8 +259,6 @@ OC.L10N.register(
     "Login canceled by app" : "Acceso cancelado pola aplicación",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non é posíbel instalar a aplicación «%1$s» por mor de non cumprirse as dependencias: %2$s",
     "a safe home for all your data" : "un acubillo seguro para todos os seus datos",
-    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, ténteo máis adiante.",
-    "Cannot download file" : "Non é posíbel descargar o ficheiro",
     "Application is not enabled" : "A aplicación non está activada",
     "Authentication error" : "Produciuse un erro de autenticación",
     "Token expired. Please reload page." : "Testemuño caducado. Recargue a páxina.",
@@ -281,10 +278,10 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Pídalle á administración do seu servidor que instale o módulo.",
     "PHP setting \"%s\" is not set to \"%s\"." : "O axuste de PHP «%s» non está estabelecido a «%s».",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Cambiar este axuste no ficheiro php.ini fará que Nextcloud funcione de novo",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está estabelecido en <code>%s</code> no canto do valor agardado <code>0</code>.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está estabelecido en <code>%s</code> en troques do valor agardado <code>0</code>.",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para solucionar este problema, estabeleza <code>mbstring.func_overload</code> en <code>0</code> no seu php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Semella que PHP foi configurado para quitar bloques de documentos en liña. Isto fará que varios aplicativos sexan inaccesíbeis. ",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha caché/acelerador como Zend OPcache ou eAccelerator.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha memoria tobo/acelerador como Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse os módulos de PHP, mais aínda aparecen listados como perdidos?",
     "Please ask your server administrator to restart the web server." : "Pídalle á administración do seu servidor que reinicie o servidor web.",
     "The required %s config variable is not configured in the config.php file." : "Precísase da variábel de configuración %s e non está configurada no ficheiro config.php.",
@@ -306,12 +303,27 @@ OC.L10N.register(
     "Storage connection error. %s" : "Produciuse un erro na conexión ao almacenamento. %s",
     "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
     "Storage connection timeout. %s" : "Esgotouse o tempo de conexión co almacenamento. %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Para permitir que esta comprobación se execute, debe asegurarse de que o seu servidor web poida conectarse a si mesmo. Por tanto, debe ser quen de resolver e conectarse a polo menos un dos seus «trusted_domains» ou ao «overwrite.cli.url». Este fallo pode ser o resultado dunha falta de coincidencia de DNS do servidor ou dunha regra da devasa de saída.",
     "Transcribe audio" : "Transcribir son",
     "Transcribe the things said in an audio" : "Transcribir as cousas ditas nun ficheiro de son",
     "Audio input" : "Entrada de son",
     "The audio to transcribe" : "O audio para transcribir",
     "Transcription" : "Transcrición",
     "The transcribed text" : "O texto transcrito",
+    "ContextAgent" : "Axente de contexto",
+    "Chat with an agent" : "Parolar cun axente",
+    "Chat message" : "Mensaxe de parola",
+    "A chat message to send to the agent." : "Unha mensaxe de parola para enviar ao axente.",
+    "Confirmation" : "Confirmación",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Indica se hai que confirmar as accións solicitadas anteriormente: 0 para a denegación e 1 para a confirmación.",
+    "Conversation token" : "Testemuño de conversa",
+    "A token representing the conversation." : "Un testemuño que representa a conversa.",
+    "Generated response" : "Resposta xerada",
+    "The response from the chat model." : "A resposta do modelo de parola.",
+    "The new conversation token" : "O novo testemuño de conversa",
+    "Send this along with the next interaction." : "Envía isto xunto coa seguinte interacción.",
+    "Requested actions by the agent" : "Accións solicitadas polo axente",
+    "Actions that the agent would like to carry out in JSON format." : "Accións que o axente quere levar a cabo en formato JSON.",
     "Context write" : "Redacción por contexto",
     "Writes text in a given style based on the provided source material." : "Escribe texto nun estilo determinado baseándose no material orixinal fornecido.",
     "Writing style" : "Estilo de escritura",
@@ -338,15 +350,29 @@ OC.L10N.register(
     "Describe a task that you want the assistant to do or ask a question" : "Describa unha tarefa que quere que realice o asistente ou formule unha pregunta",
     "Generated reply" : "Resposta xerada",
     "The generated text from the assistant" : "O texto xerado polo asistente",
+    "Change Tone" : "Cambiar o ton",
+    "Change the tone of a piece of text." : "Cambia o ton dun fragmento de texto.",
+    "Write a text that you want the assistant to rewrite in another tone." : "Escriba un texto que queira que sexa reformulado polo asistente noutro ton",
+    "Desired tone" : "Ton desexado",
+    "In which tone should your text be rewritten?" : "En que ton debe reescribirse o texto?",
+    "The rewritten text in the desired tone, written by the assistant:" : "O texto reformulado no ton desexado, escrito polo asistente",
     "Chat" : "Parola",
     "Chat with the assistant" : "Parola co asistente",
     "System prompt" : "Indicador do sistema",
     "Define rules and assumptions that the assistant should follow during the conversation." : "Definir regras e supostos que o asistente debe seguir durante a conversa.",
-    "Chat message" : "Mensaxe de parola",
     "Chat history" : "Historial de parola",
     "The history of chat messages before the current message, starting with a message by the user" : "O historial das mensaxes de parola antes da mensaxe actual, comezando cunha mensaxe do usuario",
     "Response message" : "Mensaxe de resposta",
     "The generated response as part of the conversation" : "A resposta xerada como parte da conversa",
+    "Chat with tools" : "Parola con ferramentas",
+    "Chat with the language model with tool calling support." : "Parola co modelo de linguaxe axuda da ferramenta de chamada",
+    "Tool message" : "Mensaxe da ferramenta",
+    "The result of tool calls in the last interaction" : "O resultado das chamadas de ferramenta na última interacción",
+    "Available tools" : "Ferramentas dispoñíbeis",
+    "The available tools in JSON format" : "As ferramentas dispoñíbeis en formato JSON",
+    "The response from the chat model" : "A resposta do modelo de parola",
+    "Tool calls" : "Chamadas da ferramenta",
+    "Tools call instructions from the model in JSON format" : "As ferramentas chaman ás instrucións do modelo en formato JSON",
     "Formalize text" : "Formalizar texto",
     "Takes a text and makes it sound more formal" : "Toma un texto e fai que soe máis formal",
     "Write a text that you want the assistant to formalize" : "Escriba un texto que queira que sexa formalizado polo asistente",
@@ -357,6 +383,12 @@ OC.L10N.register(
     "Original text" : "Texto orixinal",
     "The original text to generate a headline for" : "O texto orixinal para xerar un titular",
     "The generated headline" : "O titular xerado",
+    "Proofread" : "Revisión",
+    "Proofreads a text and lists corrections" : "Revisa un texto e enumera as correccións",
+    "Text" : "Texto",
+    "The text to proofread" : "O texto para revisar",
+    "Corrections" : "Correccións",
+    "The corrections that should be made in your text" : "As correccións que se deben facer no seu texto",
     "Reformulate text" : "Reformular texto",
     "Takes a text and reformulates it" : "Toma un texto e reformúlao",
     "Write a text that you want the assistant to reformulate" : "Escriba un texto que queira que sexa reformulado polo asistente",
@@ -408,7 +440,14 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
     "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
     "Set an admin username." : "Estabeleza un nome de usuario administrador",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartiu «%2$s» con Vde. e quere engadir:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartiu «%2$s» con Vde. e quere engadir",
+    "»%s« added a note to a file shared with you" : "«%s» engadiu unha nota a un ficheiro compartido con Vde.",
+    "Open »%s«" : "Abrir «%s»",
     "Sharing %s failed, because this item is already shared with user %s" : "Fallou a compartición de %s por mor de que este elemento xa foi compartido co usuario %s",
+    "%1$s shared »%2$s« with you" : "%1$s compartiu «%2$s» con Vde.",
+    "%1$s shared »%2$s« with you." : "%1$s compartiu «%2$s» con Vde.",
+    "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
     "The username is already being used" : "Este nome de usuario xa está a ser usado",
     "Could not create user" : "Non foi posíbel crear o usuario",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun nome de usuario: «a-z», «A-Z», «0-9», espazos e «_.@-'»",
@@ -417,6 +456,8 @@ OC.L10N.register(
     "Username must not consist of dots only" : "O nome de usuario non debe consistir só de puntos",
     "Username is invalid because files already exist for this user" : "O nome de usuario non é válido porque xa existen ficheiros para este usuario",
     "User disabled" : "Usuario desactivado",
+    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, ténteo máis adiante.",
+    "Cannot download file" : "Non é posíbel descargar o ficheiro",
     "Your data directory is readable by other users." : "Outros usuarios poden ler o seu directorio de datos.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outros usuarios.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrese de que existe un ficheiro chamado «.ocdata» na raíz do directorio de datos."
