@@ -92,6 +92,7 @@ OC.L10N.register(
     "Administration settings" : "Setări de administrare",
     "Settings" : "Setări",
     "Log out" : "Ieșire",
+    "Accounts" : "Conturi",
     "Email" : "E-mail",
     "View %s on the fediverse" : "Vedeți %s pe fediverse",
     "Phone" : "Telefon",
@@ -121,14 +122,7 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend-ul de partajare %s trebuie să implementeze interfața OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend-ul de partajare %s nu există",
     "Sharing backend for %s not found" : "Backend-ul de partajare pentru %s nu a fost găsit",
-    "%1$s shared »%2$s« with you" : "%1$s a partajat »%2$s« cu tine",
-    "%1$s shared »%2$s« with you." : "%1$sa partajat »%2$s« cu tine.",
-    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
-    "Open »%s«" : "Deschide »%s«",
     "%1$s via %2$s" : "%1$sprin %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s a partajat »%2$s« cu tine și vrea să adauge:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s a partajat »%2$s« cu tine și vrea să adauge",
-    "»%s« added a note to a file shared with you" : "%s« a adaugat un comentariu la un fișier partajat cu tine",
     "Unknown share type" : "Tip necunoscut de partajare",
     "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
     "Cannot increase permissions of %s" : "Nu se pot extinde permisiunile pentru %s",
@@ -190,8 +184,6 @@ OC.L10N.register(
     "Login canceled by app" : "Autentificare anulată de aplicație",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplicația \"%1$s\" nu poate fi instalată deoarece următoarele dependențe nu sunt satisfăcute: %2$s",
     "a safe home for all your data" : "o casă sigură pentru toate datele dumneavoastră",
-    "File is currently busy, please try again later" : "Fișierul este blocat momentan, încercați din nou mai târziu",
-    "Cannot download file" : "Fișierul nu se poate descărca",
     "Application is not enabled" : "Aplicația nu este activată",
     "Authentication error" : "Eroare la autentificare",
     "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
@@ -234,6 +226,7 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
     "Storage connection timeout. %s" : "Timeout la conexiunea cu spațiul de stocare. %s",
     "Generates a possible headline for a text." : "Generează un posibil titlu pentru text",
+    "Text" : "Text",
     "Summarize" : "Rezumă",
     "Summary" : "Rezumat",
     "Extract topics" : "Extrage subiecte",
@@ -259,7 +252,14 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "Numele de utilizator sau / și parola Oracle nu sunt valide",
     "PostgreSQL username and/or password not valid" : "Nume utilizator și/sau parolă PostgreSQL greșită",
     "Set an admin username." : "Setează un nume de administrator.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s a partajat »%2$s« cu tine și vrea să adauge:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s a partajat »%2$s« cu tine și vrea să adauge",
+    "»%s« added a note to a file shared with you" : "%s« a adaugat un comentariu la un fișier partajat cu tine",
+    "Open »%s«" : "Deschide »%s«",
     "Sharing %s failed, because this item is already shared with user %s" : "Partajarea %s a eșuat deoarece acest element este deja partajat cu utilizatorul %s",
+    "%1$s shared »%2$s« with you" : "%1$s a partajat »%2$s« cu tine",
+    "%1$s shared »%2$s« with you." : "%1$sa partajat »%2$s« cu tine.",
+    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
     "The username is already being used" : "Numele de utilizator este deja folosit",
     "Could not create user" : "Nu s-a putut crea utilizatorul",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Doar următoarele caractere sunt permise în numele de utilizatori: \"a-z\", \"A-Z\", \"0-9\", spații și \"_.@-'\"",
@@ -268,6 +268,8 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Numele utilizatorului nu poate conține numai puncte",
     "Username is invalid because files already exist for this user" : "Numele utilizatorului este invalid deoarece există deja fișiere pentru acesta",
     "User disabled" : "Utilizator dezactivat",
+    "File is currently busy, please try again later" : "Fișierul este blocat momentan, încercați din nou mai târziu",
+    "Cannot download file" : "Fișierul nu se poate descărca",
     "Your data directory is readable by other users." : "Directorul de date este accesibil altor utilizatori.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Setați permisiunea 0770 astfel ca directorul să nu poată fi parcurs de alți utilizatori.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asigurați-vă că fișierul \".ocdata\" există în rădăcina directorului de date."
